Class: Aws::AutoScaling::Activity

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/activity.rbs,
lib/aws-sdk-autoscaling/activity.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options = {}) ⇒ Activity #initialize(options = {}) ⇒ Activity

Returns a new instance of Activity.

Overloads:

  • #initialize(id, options = {}) ⇒ Activity

    Parameters:

    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Activity

    Options Hash (options):

    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/activity.rbs', line 13

def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#auto_scaling_group_arnString

The Amazon Resource Name (ARN) of the Auto Scaling group.

Returns:

  • (String)


52
# File 'sig/activity.rbs', line 52

def auto_scaling_group_arn: () -> ::String

#auto_scaling_group_nameString

The name of the Auto Scaling group.

Returns:

  • (String)


22
# File 'sig/activity.rbs', line 22

def auto_scaling_group_name: () -> ::String

#auto_scaling_group_stateString

The state of the Auto Scaling group, which is either InService or Deleted.

Returns:

  • (String)


49
# File 'sig/activity.rbs', line 49

def auto_scaling_group_state: () -> ::String

#causeString

The reason the activity began.

Returns:

  • (String)


28
# File 'sig/activity.rbs', line 28

def cause: () -> ::String

#clientClient

Returns:



108
# File 'lib/aws-sdk-autoscaling/activity.rb', line 108

def client: () -> Client

#dataTypes::Activity

Returns the data for this Aws::AutoScaling::Activity. Calls Client#describe_scaling_activities if #data_loaded? is false.

Returns:



61
# File 'sig/activity.rbs', line 61

def data: () -> Types::Activity

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



64
# File 'sig/activity.rbs', line 64

def data_loaded?: () -> bool

#descriptionString

A friendly, more verbose description of the activity.

Returns:

  • (String)


25
# File 'sig/activity.rbs', line 25

def description: () -> ::String

#detailsString

The details about the activity.

Returns:

  • (String)


46
# File 'sig/activity.rbs', line 46

def details: () -> ::String

#end_timeTime

The end time of the activity.

Returns:

  • (Time)


34
# File 'sig/activity.rbs', line 34

def end_time: () -> ::Time

#groupAutoScalingGroup?

Returns:



68
# File 'sig/activity.rbs', line 68

def group: () -> AutoScalingGroup?

#idString Also known as: activity_id

Returns:

  • (String)


18
# File 'sig/activity.rbs', line 18

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


257
258
259
# File 'lib/aws-sdk-autoscaling/activity.rb', line 257

def identifiers
  { id: @id }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::AutoScaling::Activity. Returns self making it possible to chain methods.

activity.reload.data

Returns:

  • (self)


57
# File 'sig/activity.rbs', line 57

def load: () -> self

#progressInteger

A value between 0 and 100 that indicates the progress of the activity.

Returns:

  • (Integer)


43
# File 'sig/activity.rbs', line 43

def progress: () -> ::Integer

#start_timeTime

The start time of the activity.

Returns:

  • (Time)


31
# File 'sig/activity.rbs', line 31

def start_time: () -> ::Time

#status_codeString

The current status of the activity.

Returns:

  • (String)


37
# File 'sig/activity.rbs', line 37

def status_code: () -> ("PendingSpotBidPlacement" | "WaitingForSpotInstanceRequestId" | "WaitingForSpotInstanceId" | "WaitingForInstanceId" | "PreInService" | "InProgress" | "WaitingForELBConnectionDraining" | "MidLifecycleAction" | "WaitingForInstanceWarmup" | "Successful" | "Failed" | "Cancelled" | "WaitingForConnectionDraining" | "WaitingForInPlaceUpdateToStart" | "WaitingForInPlaceUpdateToFinalize" | "InPlaceUpdateInProgress")

#status_messageString

A friendly, more verbose description of the activity status.

Returns:

  • (String)


40
# File 'sig/activity.rbs', line 40

def status_message: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::AutoScaling::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/aws-sdk-autoscaling/activity.rb', line 222

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end