Class: Aws::AutoScaling::AutoScalingGroup
- Inherits:
-
Object
- Object
- Aws::AutoScaling::AutoScalingGroup
- Extended by:
- Deprecations
- Defined in:
- sig/auto_scaling_group.rbs,
lib/aws-sdk-autoscaling/auto_scaling_group.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#auto_scaling_group_arn ⇒ String
The Amazon Resource Name (ARN) of the Auto Scaling group.
-
#availability_zone_distribution ⇒ Types::AvailabilityZoneDistribution
The EC2 instance capacity distribution across Availability Zones for the Auto Scaling group.
-
#availability_zone_ids ⇒ Array<String>
The Availability Zone IDs where the Auto Scaling group can launch instances.
-
#availability_zone_impairment_policy ⇒ Types::AvailabilityZoneImpairmentPolicy
The Availability Zone impairment policy for the Auto Scaling group.
-
#availability_zones ⇒ Array<String>
One or more Availability Zones for the Auto Scaling group.
-
#capacity_rebalance ⇒ Boolean
Indicates whether Capacity Rebalancing is enabled.
-
#capacity_reservation_specification ⇒ Types::CapacityReservationSpecification
The capacity reservation specification for the Auto Scaling group.
-
#context ⇒ String
Reserved.
-
#created_time ⇒ Time
The date and time the Auto Scaling group was created.
-
#default_cooldown ⇒ Integer
The duration of the default cooldown period, in seconds, for the Auto Scaling group.
-
#default_instance_warmup ⇒ Integer
The duration of the default EC2 instance warmup time, in seconds, for the Auto Scaling group.
-
#deletion_protection ⇒ String
The deletion protection setting for the Auto Scaling group.
-
#desired_capacity ⇒ Integer
The desired size of the Auto Scaling group.
-
#desired_capacity_type ⇒ String
The unit of measurement for the value specified for desired capacity.
-
#enabled_metrics ⇒ Array<Types::EnabledMetric>
The metrics enabled for the Auto Scaling group.
-
#health_check_grace_period ⇒ Integer
The duration of the health check grace period, in seconds, for the Auto Scaling group.
-
#health_check_type ⇒ String
One or more comma-separated health check types for the Auto Scaling group.
-
#instance_lifecycle_policy ⇒ Types::InstanceLifecyclePolicy
The instance lifecycle policy for the Auto Scaling group.
-
#instance_maintenance_policy ⇒ Types::InstanceMaintenancePolicy
An instance maintenance policy.
-
#launch_configuration_name ⇒ String
The name of the associated launch configuration for the Auto Scaling group.
-
#launch_template ⇒ Types::LaunchTemplateSpecification
The launch template for the Auto Scaling group.
-
#load_balancer_names ⇒ Array<String>
One or more load balancers associated with the group.
-
#max_instance_lifetime ⇒ Integer
The maximum amount of time, in seconds, that an EC2 instance can be in service for the Auto Scaling group.
-
#max_size ⇒ Integer
The maximum size of the Auto Scaling group.
-
#min_size ⇒ Integer
The minimum size of the Auto Scaling group.
-
#mixed_instances_policy ⇒ Types::MixedInstancesPolicy
The mixed instances policy for the group.
- #name ⇒ String (also: #auto_scaling_group_name)
-
#new_instances_protected_from_scale_in ⇒ Boolean
Indicates whether newly launched EC2 instances are protected from termination when scaling in for the Auto Scaling group.
-
#operator ⇒ Types::Operator
The entity that manages the Auto Scaling group, if applicable.
-
#placement_group ⇒ String
The name of the placement group into which to launch EC2 instances for the Auto Scaling group.
-
#predicted_capacity ⇒ Integer
The predicted capacity of the group when it has a predictive scaling policy.
-
#service_linked_role_arn ⇒ String
The Amazon Resource Name (ARN) of the service-linked role that the Auto Scaling group uses to call other Amazon Web Services on your behalf.
-
#status ⇒ String
The current state of the Auto Scaling group when the [DeleteAutoScalingGroup][1] operation is in progress.
-
#suspended_processes ⇒ Array<Types::SuspendedProcess>
The suspended processes associated with the Auto Scaling group.
-
#target_group_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the target groups for your load balancer.
-
#termination_policies ⇒ Array<String>
The termination policies for the Auto Scaling group.
-
#traffic_sources ⇒ Array<Types::TrafficSourceIdentifier>
The traffic sources associated with this Auto Scaling group.
-
#vpc_zone_identifier ⇒ String
One or more comma-separated subnet IDs for the Auto Scaling group.
-
#warm_pool_configuration ⇒ Types::WarmPoolConfiguration
The warm pool for the group.
-
#warm_pool_size ⇒ Integer
The current size of the warm pool.
Actions collapse
- #attach_instances(options = {}) ⇒ EmptyStructure
- #delete(options = {}) ⇒ EmptyStructure
- #detach_instances(options = {}) ⇒ Activity::Collection
- #disable_metrics_collection(options = {}) ⇒ EmptyStructure
- #enable_metrics_collection(options = {}) ⇒ EmptyStructure
- #put_scaling_policy(options = {}) ⇒ ScalingPolicy
- #put_scheduled_update_group_action(options = {}) ⇒ ScheduledAction
- #resume_processes(options = {}) ⇒ EmptyStructure
- #set_desired_capacity(options = {}) ⇒ EmptyStructure
- #suspend_processes(options = {}) ⇒ EmptyStructure
- #update(options = {}) ⇒ AutoScalingGroup
Associations collapse
- #activities(options = {}) ⇒ Activity::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
- #instances ⇒ Instance::Collection
- #launch_configuration ⇒ LaunchConfiguration?
- #lifecycle_hook(name) ⇒ LifecycleHook
- #lifecycle_hooks(options = {}) ⇒ LifecycleHook::Collection
- #load_balancer(name) ⇒ LoadBalancer
- #load_balancers(options = {}) ⇒ LoadBalancer::Collection
- #notification_configurations(options = {}) ⇒ NotificationConfiguration::Collection
- #policies(options = {}) ⇒ ScalingPolicy::Collection
- #scheduled_actions(options = {}) ⇒ ScheduledAction::Collection
- #tag(key) ⇒ Tag
- #tags ⇒ Tag::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::AutoScalingGroup
Returns the data for this AutoScalingGroup.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#exists?(options = {}) ⇒ Boolean
Returns
trueif the AutoScalingGroup exists. -
#initialize(*args) ⇒ AutoScalingGroup
constructor
A new instance of AutoScalingGroup.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current AutoScalingGroup.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::AutoScaling::Client] #wait_until instead
- #wait_until_exists(options = {}, &block) ⇒ AutoScalingGroup
- #wait_until_in_service(options = {}, &block) ⇒ AutoScalingGroup
- #wait_until_not_exists(options = {}, &block) ⇒ AutoScalingGroup
Constructor Details
#initialize(name, options = {}) ⇒ AutoScalingGroup #initialize(options = {}) ⇒ AutoScalingGroup
Returns a new instance of AutoScalingGroup.
13 14 15 |
# File 'sig/auto_scaling_group.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#activities(options = {}) ⇒ Activity::Collection
539 |
# File 'sig/auto_scaling_group.rbs', line 539
def activities: (
|
#attach_instances(options = {}) ⇒ EmptyStructure
167 |
# File 'sig/auto_scaling_group.rbs', line 167
def attach_instances: (
|
#auto_scaling_group_arn ⇒ String
The Amazon Resource Name (ARN) of the Auto Scaling group.
22 |
# File 'sig/auto_scaling_group.rbs', line 22
def auto_scaling_group_arn: () -> ::String
|
#availability_zone_distribution ⇒ Types::AvailabilityZoneDistribution
The EC2 instance capacity distribution across Availability Zones for the Auto Scaling group.
124 |
# File 'sig/auto_scaling_group.rbs', line 124
def availability_zone_distribution: () -> Types::AvailabilityZoneDistribution
|
#availability_zone_ids ⇒ Array<String>
The Availability Zone IDs where the Auto Scaling group can launch instances.
52 |
# File 'sig/auto_scaling_group.rbs', line 52
def availability_zone_ids: () -> ::Array[::String]
|
#availability_zone_impairment_policy ⇒ Types::AvailabilityZoneImpairmentPolicy
The Availability Zone impairment policy for the Auto Scaling group.
127 |
# File 'sig/auto_scaling_group.rbs', line 127
def availability_zone_impairment_policy: () -> Types::AvailabilityZoneImpairmentPolicy
|
#availability_zones ⇒ Array<String>
One or more Availability Zones for the Auto Scaling group.
49 |
# File 'sig/auto_scaling_group.rbs', line 49
def availability_zones: () -> ::Array[::String]
|
#capacity_rebalance ⇒ Boolean
Indicates whether Capacity Rebalancing is enabled.
97 |
# File 'sig/auto_scaling_group.rbs', line 97
def capacity_rebalance: () -> bool
|
#capacity_reservation_specification ⇒ Types::CapacityReservationSpecification
The capacity reservation specification for the Auto Scaling group.
130 |
# File 'sig/auto_scaling_group.rbs', line 130
def capacity_reservation_specification: () -> Types::CapacityReservationSpecification
|
#client ⇒ Client
306 |
# File 'lib/aws-sdk-autoscaling/auto_scaling_group.rb', line 306
def client: () -> Client
|
#context ⇒ String
Reserved.
106 |
# File 'sig/auto_scaling_group.rbs', line 106
def context: () -> ::String
|
#created_time ⇒ Time
The date and time the Auto Scaling group was created.
67 |
# File 'sig/auto_scaling_group.rbs', line 67
def created_time: () -> ::Time
|
#data ⇒ Types::AutoScalingGroup
Returns the data for this Aws::AutoScaling::AutoScalingGroup. Calls
Client#describe_auto_scaling_groups if #data_loaded? is false.
145 |
# File 'sig/auto_scaling_group.rbs', line 145
def data: () -> Types::AutoScalingGroup
|
#data_loaded? ⇒ Boolean
148 |
# File 'sig/auto_scaling_group.rbs', line 148
def data_loaded?: () -> bool
|
#default_cooldown ⇒ Integer
The duration of the default cooldown period, in seconds, for the Auto Scaling group.
46 |
# File 'sig/auto_scaling_group.rbs', line 46
def default_cooldown: () -> ::Integer
|
#default_instance_warmup ⇒ Integer
The duration of the default EC2 instance warmup time, in seconds, for the Auto Scaling group.
112 |
# File 'sig/auto_scaling_group.rbs', line 112
def default_instance_warmup: () -> ::Integer
|
#delete(options = {}) ⇒ EmptyStructure
173 |
# File 'sig/auto_scaling_group.rbs', line 173
def delete: (
|
#deletion_protection ⇒ String
The deletion protection setting for the Auto Scaling group.
121 |
# File 'sig/auto_scaling_group.rbs', line 121
def deletion_protection: () -> ("none" | "prevent-force-deletion" | "prevent-all-deletion")
|
#desired_capacity ⇒ Integer
The desired size of the Auto Scaling group.
40 |
# File 'sig/auto_scaling_group.rbs', line 40
def desired_capacity: () -> ::Integer
|
#desired_capacity_type ⇒ String
The unit of measurement for the value specified for desired capacity.
Amazon EC2 Auto Scaling supports DesiredCapacityType for
attribute-based instance type selection only.
109 |
# File 'sig/auto_scaling_group.rbs', line 109
def desired_capacity_type: () -> ::String
|
#detach_instances(options = {}) ⇒ Activity::Collection
179 |
# File 'sig/auto_scaling_group.rbs', line 179
def detach_instances: (
|
#disable_metrics_collection(options = {}) ⇒ EmptyStructure
186 |
# File 'sig/auto_scaling_group.rbs', line 186
def disable_metrics_collection: (
|
#enable_metrics_collection(options = {}) ⇒ EmptyStructure
192 |
# File 'sig/auto_scaling_group.rbs', line 192
def enable_metrics_collection: (
|
#enabled_metrics ⇒ Array<Types::EnabledMetric>
The metrics enabled for the Auto Scaling group.
79 |
# File 'sig/auto_scaling_group.rbs', line 79
def enabled_metrics: () -> ::Array[Types::EnabledMetric]
|
#exists?(options = {}) ⇒ Boolean
Returns true if the AutoScalingGroup exists.
151 152 |
# File 'sig/auto_scaling_group.rbs', line 151
def exists?: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) -> bool
| (?Hash[Symbol, untyped]) -> bool
|
#health_check_grace_period ⇒ Integer
The duration of the health check grace period, in seconds, for the Auto Scaling group.
64 |
# File 'sig/auto_scaling_group.rbs', line 64
def health_check_grace_period: () -> ::Integer
|
#health_check_type ⇒ String
One or more comma-separated health check types for the Auto Scaling group.
61 |
# File 'sig/auto_scaling_group.rbs', line 61
def health_check_type: () -> ::String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1958 1959 1960 |
# File 'lib/aws-sdk-autoscaling/auto_scaling_group.rb', line 1958 def identifiers { name: @name } end |
#instance_lifecycle_policy ⇒ Types::InstanceLifecyclePolicy
The instance lifecycle policy for the Auto Scaling group.
133 |
# File 'sig/auto_scaling_group.rbs', line 133
def instance_lifecycle_policy: () -> Types::InstanceLifecyclePolicy
|
#instance_maintenance_policy ⇒ Types::InstanceMaintenancePolicy
An instance maintenance policy.
118 |
# File 'sig/auto_scaling_group.rbs', line 118
def instance_maintenance_policy: () -> Types::InstanceMaintenancePolicy
|
#instances ⇒ Instance::Collection
552 |
# File 'sig/auto_scaling_group.rbs', line 552
def instances: () -> Instance::Collection
|
#launch_configuration ⇒ LaunchConfiguration?
555 |
# File 'sig/auto_scaling_group.rbs', line 555
def launch_configuration: () -> LaunchConfiguration?
|
#launch_configuration_name ⇒ String
The name of the associated launch configuration for the Auto Scaling group.
25 |
# File 'sig/auto_scaling_group.rbs', line 25
def launch_configuration_name: () -> ::String
|
#launch_template ⇒ Types::LaunchTemplateSpecification
The launch template for the Auto Scaling group.
28 |
# File 'sig/auto_scaling_group.rbs', line 28
def launch_template: () -> Types::LaunchTemplateSpecification
|
#lifecycle_hook(name) ⇒ LifecycleHook
558 |
# File 'sig/auto_scaling_group.rbs', line 558
def lifecycle_hook: (String name) -> LifecycleHook
|
#lifecycle_hooks(options = {}) ⇒ LifecycleHook::Collection
561 |
# File 'sig/auto_scaling_group.rbs', line 561
def lifecycle_hooks: (
|
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::AutoScaling::AutoScalingGroup.
Returns self making it possible to chain methods.
auto_scaling_group.reload.data
141 |
# File 'sig/auto_scaling_group.rbs', line 141
def load: () -> self
|
#load_balancer(name) ⇒ LoadBalancer
567 |
# File 'sig/auto_scaling_group.rbs', line 567
def load_balancer: (String name) -> LoadBalancer
|
#load_balancer_names ⇒ Array<String>
One or more load balancers associated with the group.
55 |
# File 'sig/auto_scaling_group.rbs', line 55
def load_balancer_names: () -> ::Array[::String]
|
#load_balancers(options = {}) ⇒ LoadBalancer::Collection
570 |
# File 'sig/auto_scaling_group.rbs', line 570
def load_balancers: (
|
#max_instance_lifetime ⇒ Integer
The maximum amount of time, in seconds, that an EC2 instance can be in service for the Auto Scaling group.
94 |
# File 'sig/auto_scaling_group.rbs', line 94
def max_instance_lifetime: () -> ::Integer
|
#max_size ⇒ Integer
The maximum size of the Auto Scaling group.
37 |
# File 'sig/auto_scaling_group.rbs', line 37
def max_size: () -> ::Integer
|
#min_size ⇒ Integer
The minimum size of the Auto Scaling group.
34 |
# File 'sig/auto_scaling_group.rbs', line 34
def min_size: () -> ::Integer
|
#mixed_instances_policy ⇒ Types::MixedInstancesPolicy
The mixed instances policy for the group.
31 |
# File 'sig/auto_scaling_group.rbs', line 31
def mixed_instances_policy: () -> Types::MixedInstancesPolicy
|
#name ⇒ String Also known as: auto_scaling_group_name
18 |
# File 'sig/auto_scaling_group.rbs', line 18
def name: () -> String
|
#new_instances_protected_from_scale_in ⇒ Boolean
Indicates whether newly launched EC2 instances are protected from termination when scaling in for the Auto Scaling group.
For more information about preventing instances from terminating on scale in, see Use instance scale-in protection in the Amazon EC2 Auto Scaling User Guide.
88 |
# File 'sig/auto_scaling_group.rbs', line 88
def new_instances_protected_from_scale_in: () -> bool
|
#notification_configurations(options = {}) ⇒ NotificationConfiguration::Collection
575 |
# File 'sig/auto_scaling_group.rbs', line 575
def notification_configurations: (
|
#operator ⇒ Types::Operator
The entity that manages the Auto Scaling group, if applicable. When set, only the designated operator can make changes to the group configuration.
136 |
# File 'sig/auto_scaling_group.rbs', line 136
def operator: () -> Types::Operator
|
#placement_group ⇒ String
The name of the placement group into which to launch EC2 instances for the Auto Scaling group.
73 |
# File 'sig/auto_scaling_group.rbs', line 73
def placement_group: () -> ::String
|
#policies(options = {}) ⇒ ScalingPolicy::Collection
580 |
# File 'sig/auto_scaling_group.rbs', line 580
def policies: (
|
#predicted_capacity ⇒ Integer
The predicted capacity of the group when it has a predictive scaling policy.
43 |
# File 'sig/auto_scaling_group.rbs', line 43
def predicted_capacity: () -> ::Integer
|
#put_scaling_policy(options = {}) ⇒ ScalingPolicy
199 |
# File 'sig/auto_scaling_group.rbs', line 199
def put_scaling_policy: (
|
#put_scheduled_update_group_action(options = {}) ⇒ ScheduledAction
361 |
# File 'sig/auto_scaling_group.rbs', line 361
def put_scheduled_update_group_action: (
|
#resume_processes(options = {}) ⇒ EmptyStructure
375 |
# File 'sig/auto_scaling_group.rbs', line 375
def resume_processes: (
|
#scheduled_actions(options = {}) ⇒ ScheduledAction::Collection
587 |
# File 'sig/auto_scaling_group.rbs', line 587
def scheduled_actions: (
|
#service_linked_role_arn ⇒ String
The Amazon Resource Name (ARN) of the service-linked role that the Auto Scaling group uses to call other Amazon Web Services on your behalf.
91 |
# File 'sig/auto_scaling_group.rbs', line 91
def service_linked_role_arn: () -> ::String
|
#set_desired_capacity(options = {}) ⇒ EmptyStructure
381 |
# File 'sig/auto_scaling_group.rbs', line 381
def set_desired_capacity: (
|
#status ⇒ String
The current state of the Auto Scaling group when the DeleteAutoScalingGroup operation is in progress.
82 |
# File 'sig/auto_scaling_group.rbs', line 82
def status: () -> ::String
|
#suspend_processes(options = {}) ⇒ EmptyStructure
388 |
# File 'sig/auto_scaling_group.rbs', line 388
def suspend_processes: (
|
#suspended_processes ⇒ Array<Types::SuspendedProcess>
The suspended processes associated with the Auto Scaling group.
70 |
# File 'sig/auto_scaling_group.rbs', line 70
def suspended_processes: () -> ::Array[Types::SuspendedProcess]
|
#tags ⇒ Tag::Collection
598 |
# File 'sig/auto_scaling_group.rbs', line 598
def tags: () -> Tag::Collection
|
#target_group_arns ⇒ Array<String>
The Amazon Resource Names (ARN) of the target groups for your load balancer.
58 |
# File 'sig/auto_scaling_group.rbs', line 58
def target_group_arns: () -> ::Array[::String]
|
#termination_policies ⇒ Array<String>
The termination policies for the Auto Scaling group.
85 |
# File 'sig/auto_scaling_group.rbs', line 85
def termination_policies: () -> ::Array[::String]
|
#traffic_sources ⇒ Array<Types::TrafficSourceIdentifier>
The traffic sources associated with this Auto Scaling group.
115 |
# File 'sig/auto_scaling_group.rbs', line 115
def traffic_sources: () -> ::Array[Types::TrafficSourceIdentifier]
|
#update(options = {}) ⇒ AutoScalingGroup
394 |
# File 'sig/auto_scaling_group.rbs', line 394
def update: (
|
#vpc_zone_identifier ⇒ String
One or more comma-separated subnet IDs for the Auto Scaling group.
76 |
# File 'sig/auto_scaling_group.rbs', line 76
def vpc_zone_identifier: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::AutoScaling::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-autoscaling/auto_scaling_group.rb', line 491 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |
#wait_until_exists(options = {}, &block) ⇒ AutoScalingGroup
155 156 |
# File 'sig/auto_scaling_group.rbs', line 155
def wait_until_exists: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) ?{ (untyped waiter) -> void } -> AutoScalingGroup
| (?Hash[Symbol, untyped]) ?{ (untyped waiter) -> void } -> AutoScalingGroup
|
#wait_until_in_service(options = {}, &block) ⇒ AutoScalingGroup
159 160 |
# File 'sig/auto_scaling_group.rbs', line 159
def wait_until_in_service: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) ?{ (untyped waiter) -> void } -> AutoScalingGroup
| (?Hash[Symbol, untyped]) ?{ (untyped waiter) -> void } -> AutoScalingGroup
|
#wait_until_not_exists(options = {}, &block) ⇒ AutoScalingGroup
163 164 |
# File 'sig/auto_scaling_group.rbs', line 163
def wait_until_not_exists: (?max_attempts: Integer, ?delay: Numeric, ?before_attempt: (^(Integer attempts) -> void), ?before_wait: (^(Integer attempts, untyped response) -> void)) ?{ (untyped waiter) -> void } -> AutoScalingGroup
| (?Hash[Symbol, untyped]) ?{ (untyped waiter) -> void } -> AutoScalingGroup
|
#warm_pool_configuration ⇒ Types::WarmPoolConfiguration
The warm pool for the group.
100 |
# File 'sig/auto_scaling_group.rbs', line 100
def warm_pool_configuration: () -> Types::WarmPoolConfiguration
|
#warm_pool_size ⇒ Integer
The current size of the warm pool.
103 |
# File 'sig/auto_scaling_group.rbs', line 103
def warm_pool_size: () -> ::Integer
|