Class: Aws::AutoScaling::Instance

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/instance.rbs,
lib/aws-sdk-autoscaling/instance.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(group_name, id, options = {}) ⇒ Instance #initialize(options = {}) ⇒ Instance

Returns a new instance of Instance.

Overloads:

  • #initialize(group_name, id, options = {}) ⇒ Instance

    Parameters:

    • group_name (String)
    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Instance

    Options Hash (options):

    • :group_name (required, String)
    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/instance.rbs', line 13

def initialize: (String group_name, String id, Hash[Symbol, untyped] options) -> void
| (group_name: String, id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#attach(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


instance.attach()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


69
# File 'sig/instance.rbs', line 69

def attach: (

#availability_zoneString

The Availability Zone for the instance.

Returns:

  • (String)


29
# File 'sig/instance.rbs', line 29

def availability_zone: () -> ::String

#availability_zone_idString

The Availability Zone ID where the instance is located.

Returns:

  • (String)


32
# File 'sig/instance.rbs', line 32

def availability_zone_id: () -> ::String

#clientClient

Returns:



152
# File 'lib/aws-sdk-autoscaling/instance.rb', line 152

def client: () -> Client

#dataTypes::AutoScalingInstanceDetails



62
# File 'sig/instance.rbs', line 62

def data: () -> Types::AutoScalingInstanceDetails

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



65
# File 'sig/instance.rbs', line 65

def data_loaded?: () -> bool

#detach(options = {}) ⇒ Activity::Collection

Examples:

Request syntax with placeholder values


activity = instance.detach({
  should_decrement_desired_capacity: false, # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :should_decrement_desired_capacity (required, Boolean)

    Indicates whether the Auto Scaling group decrements the desired capacity value by the number of instances detached.

Returns:



74
# File 'sig/instance.rbs', line 74

def detach: (

#enter_standby(options = {}) ⇒ Activity::Collection

Examples:

Request syntax with placeholder values


activity = instance.enter_standby({
  should_decrement_desired_capacity: false, # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :should_decrement_desired_capacity (required, Boolean)

    Indicates whether to decrement the desired capacity of the Auto Scaling group by the number of instances moved to Standby mode.

Returns:



80
# File 'sig/instance.rbs', line 80

def enter_standby: (

#exit_standby(options = {}) ⇒ Activity::Collection

Examples:

Request syntax with placeholder values


instance.exit_standby()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



86
# File 'sig/instance.rbs', line 86

def exit_standby: (

#groupAutoScalingGroup

Returns:



104
# File 'sig/instance.rbs', line 104

def group: () -> AutoScalingGroup

#group_nameString Also known as: auto_scaling_group_name

Returns:

  • (String)


18
# File 'sig/instance.rbs', line 18

def group_name: () -> String

#health_statusString

The last reported health status of this instance. Healthy means that the instance is healthy and should remain in service. Unhealthy means that the instance is unhealthy and Amazon EC2 Auto Scaling should terminate and replace it.

Returns:

  • (String)


38
# File 'sig/instance.rbs', line 38

def health_status: () -> ::String

#idString Also known as: instance_id

Returns:

  • (String)


22
# File 'sig/instance.rbs', line 22

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


465
466
467
468
469
470
# File 'lib/aws-sdk-autoscaling/instance.rb', line 465

def identifiers
  {
    group_name: @group_name,
    id: @id
  }
end

#image_idString

The ID of the Amazon Machine Image (AMI) associated with the instance. This field shows the current AMI ID of the instance's root volume. It may differ from the original AMI used when the instance was first launched.

This field appears for:

  • Instances with root volume replacements through Instance Refresh

  • Instances launched with AMI overrides

This field won't appear for:

  • Existing instances launched from Launch Templates without overrides

  • Existing instances that didn’t have their root volume replaced through Instance Refresh

Returns:

  • (String)


47
# File 'sig/instance.rbs', line 47

def image_id: () -> ::String

#instance_typeString

The instance type of the EC2 instance.

Returns:

  • (String)


26
# File 'sig/instance.rbs', line 26

def instance_type: () -> ::String

#launch_configurationLaunchConfiguration?

Returns:



107
# File 'sig/instance.rbs', line 107

def launch_configuration: () -> LaunchConfiguration?

#launch_configuration_nameString

The launch configuration used to launch the instance. This value is not available if you attached the instance to the Auto Scaling group.

Returns:

  • (String)


41
# File 'sig/instance.rbs', line 41

def launch_configuration_name: () -> ::String

#launch_templateTypes::LaunchTemplateSpecification

The launch template for the instance.



44
# File 'sig/instance.rbs', line 44

def launch_template: () -> Types::LaunchTemplateSpecification

#lifecycle_stateString

The lifecycle state for the instance. The Quarantined state is not used. For more information, see Amazon EC2 Auto Scaling instance lifecycle in the Amazon EC2 Auto Scaling User Guide.

Valid values: Pending | Pending:Wait | Pending:Proceed | Quarantined | InService | Terminating | Terminating:Wait | Terminating:Proceed | Terminating:Retained | Terminated | Detaching | Detached | EnteringStandby | Standby | ReplacingRootVolume | ReplacingRootVolume:Wait | ReplacingRootVolume:Proceed | RootVolumeReplaced | Warmed:Pending | Warmed:Pending:Wait | Warmed:Pending:Proceed | Warmed:Pending:Retained | Warmed:Terminating | Warmed:Terminating:Wait | Warmed:Terminating:Proceed | Warmed:Terminating:Retained | Warmed:Terminated | Warmed:Stopped | Warmed:Running | Warmed:Hibernated

Returns:

  • (String)


35
# File 'sig/instance.rbs', line 35

def lifecycle_state: () -> ::String

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::AutoScaling::Instance. Returns self making it possible to chain methods.

instance.reload.data

Returns:

  • (self)


58
# File 'sig/instance.rbs', line 58

def load: () -> self

#protected_from_scale_inBoolean

Indicates whether the instance is protected from termination by Amazon EC2 Auto Scaling when scaling in.

Returns:

  • (Boolean)


50
# File 'sig/instance.rbs', line 50

def protected_from_scale_in: () -> bool

#set_health(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


instance.set_health({
  health_status: "XmlStringMaxLen32", # required
  should_respect_grace_period: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :health_status (required, String)

    The health status of the instance. Set to Healthy to have the instance remain in service. Set to Unhealthy to have the instance be out of service. Amazon EC2 Auto Scaling terminates and replaces the unhealthy instance.

  • :should_respect_grace_period (Boolean)

    If the Auto Scaling group of the specified instance has a HealthCheckGracePeriod specified for the group, by default, this call respects the grace period. Set this to False, to have the call not respect the grace period associated with the group.

    For more information about the health check grace period, see Set the health check grace period for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.

Returns:

  • (EmptyStructure)


91
# File 'sig/instance.rbs', line 91

def set_health: (

#terminate(options = {}) ⇒ Activity

Examples:

Request syntax with placeholder values


activity = instance.terminate({
  should_decrement_desired_capacity: false, # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :should_decrement_desired_capacity (required, Boolean)

    Indicates whether terminating the instance also decrements the size of the Auto Scaling group.

Returns:



98
# File 'sig/instance.rbs', line 98

def terminate: (

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::AutoScaling::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/aws-sdk-autoscaling/instance.rb', line 266

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end

#weighted_capacityString

The number of capacity units contributed by the instance based on its instance type.

Valid Range: Minimum value of 1. Maximum value of 999.

Returns:

  • (String)


53
# File 'sig/instance.rbs', line 53

def weighted_capacity: () -> ::String