Class: Aws::AutoScaling::LoadBalancer

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/load_balancer.rbs,
lib/aws-sdk-autoscaling/load_balancer.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(group_name, name, options = {}) ⇒ LoadBalancer #initialize(options = {}) ⇒ LoadBalancer

Returns a new instance of LoadBalancer.

Overloads:

  • #initialize(group_name, name, options = {}) ⇒ LoadBalancer

    Parameters:

    • group_name (String)
    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ LoadBalancer

    Options Hash (options):

    • :group_name (required, String)
    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/load_balancer.rbs', line 13

def initialize: (String group_name, String name, Hash[Symbol, untyped] options) -> void
| (group_name: String, name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#attach(options = {}) ⇒ Types::AttachLoadBalancersResultType

Examples:

Request syntax with placeholder values


load_balancer.attach()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



38
# File 'sig/load_balancer.rbs', line 38

def attach: (

#clientClient

Returns:



72
# File 'lib/aws-sdk-autoscaling/load_balancer.rb', line 72

def client: () -> Client

#dataTypes::LoadBalancerState

Returns the data for this Aws::AutoScaling::LoadBalancer.

Returns:

Raises:



31
# File 'sig/load_balancer.rbs', line 31

def data: () -> Types::LoadBalancerState

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



34
# File 'sig/load_balancer.rbs', line 34

def data_loaded?: () -> bool

#detach(options = {}) ⇒ Types::DetachLoadBalancersResultType

Examples:

Request syntax with placeholder values


load_balancer.detach()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



43
# File 'sig/load_balancer.rbs', line 43

def detach: (

#groupAutoScalingGroup

Returns:



48
# File 'sig/load_balancer.rbs', line 48

def group: () -> AutoScalingGroup

#group_nameString

Returns:

  • (String)


18
# File 'sig/load_balancer.rbs', line 18

def group_name: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


244
245
246
247
248
249
# File 'lib/aws-sdk-autoscaling/load_balancer.rb', line 244

def identifiers
  {
    group_name: @group_name,
    name: @name
  }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


78
79
80
81
# File 'lib/aws-sdk-autoscaling/load_balancer.rb', line 78

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#nameString Also known as: load_balancer_name

Returns:

  • (String)


21
# File 'sig/load_balancer.rbs', line 21

def name: () -> String

#stateString

One of the following load balancer states:

  • Adding - The Auto Scaling instances are being registered with the load balancer.

  • Added - All Auto Scaling instances are registered with the load balancer.

  • InService - At least one Auto Scaling instance passed an ELB health check.

  • Removing - The Auto Scaling instances are being deregistered from the load balancer. If connection draining is enabled, Elastic Load Balancing waits for in-flight requests to complete before deregistering the instances.

  • Removed - All Auto Scaling instances are deregistered from the load balancer.

Returns:

  • (String)


25
# File 'sig/load_balancer.rbs', line 25

def state: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::AutoScaling::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/aws-sdk-autoscaling/load_balancer.rb', line 179

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end