Class: Aws::AutoScaling::NotificationConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/notification_configuration.rbs,
lib/aws-sdk-autoscaling/notification_configuration.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(group_name, type, topic_arn, options = {}) ⇒ NotificationConfiguration #initialize(options = {}) ⇒ NotificationConfiguration

Returns a new instance of NotificationConfiguration.

Overloads:

  • #initialize(group_name, type, topic_arn, options = {}) ⇒ NotificationConfiguration

    Parameters:

    • group_name (String)
    • type (String)
    • topic_arn (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ NotificationConfiguration

    Options Hash (options):

    • :group_name (required, String)
    • :type (required, String)
    • :topic_arn (required, String)
    • :client (Client)


13
14
15
# File 'sig/notification_configuration.rbs', line 13

def initialize: (String group_name, String type, String topic_arn, Hash[Symbol, untyped] options) -> void
| (group_name: String, type: String, topic_arn: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



58
# File 'lib/aws-sdk-autoscaling/notification_configuration.rb', line 58

def client: () -> Client

#dataTypes::NotificationConfiguration

Returns the data for this Aws::AutoScaling::NotificationConfiguration.

Returns:

Raises:



32
# File 'sig/notification_configuration.rbs', line 32

def data: () -> Types::NotificationConfiguration

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



35
# File 'sig/notification_configuration.rbs', line 35

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


notification_configuration.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


39
# File 'sig/notification_configuration.rbs', line 39

def delete: (

#groupAutoScalingGroup

Returns:



49
# File 'sig/notification_configuration.rbs', line 49

def group: () -> AutoScalingGroup

#group_nameString Also known as: auto_scaling_group_name

Returns:

  • (String)


18
# File 'sig/notification_configuration.rbs', line 18

def group_name: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


231
232
233
234
235
236
237
# File 'lib/aws-sdk-autoscaling/notification_configuration.rb', line 231

def identifiers
  {
    group_name: @group_name,
    type: @type,
    topic_arn: @topic_arn
  }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


64
65
66
67
# File 'lib/aws-sdk-autoscaling/notification_configuration.rb', line 64

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#put(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


notification_configuration.put()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


44
# File 'sig/notification_configuration.rbs', line 44

def put: (

#topic_arnString

Returns:

  • (String)


26
# File 'sig/notification_configuration.rbs', line 26

def topic_arn: () -> String

#typeString Also known as: notification_type

Returns:

  • (String)


22
# File 'sig/notification_configuration.rbs', line 22

def type: () -> String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::AutoScaling::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/aws-sdk-autoscaling/notification_configuration.rb', line 165

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end