Class: Aws::AutoScaling::Resource
- Inherits:
-
Object
- Object
- Aws::AutoScaling::Resource
- Defined in:
- sig/resource.rbs,
lib/aws-sdk-autoscaling/resource.rb
Overview
This class provides a resource oriented interface for AutoScaling. To create a resource object:
resource = Aws::AutoScaling::Resource.new(region: 'us-west-2')
You can supply a client object with custom configuration that will be used for all resource operations.
If you do not pass :client, a default client will be constructed.
client = Aws::AutoScaling::Client.new(region: 'us-west-2')
resource = Aws::AutoScaling::Resource.new(client: client)
Actions collapse
- #create_group(options = {}) ⇒ AutoScalingGroup
- #create_launch_configuration(options = {}) ⇒ LaunchConfiguration
Associations collapse
- #activities(options = {}) ⇒ Activity::Collection
- #activity(id) ⇒ Activity
- #group(name) ⇒ AutoScalingGroup
- #groups(options = {}) ⇒ AutoScalingGroup::Collection
- #instances(options = {}) ⇒ Instance::Collection
- #launch_configuration(name) ⇒ LaunchConfiguration
- #launch_configurations(options = {}) ⇒ LaunchConfiguration::Collection
- #policies(options = {}) ⇒ ScalingPolicy::Collection
- #policy(name) ⇒ ScalingPolicy
- #scheduled_action(name) ⇒ ScheduledAction
- #scheduled_actions(options = {}) ⇒ ScheduledAction::Collection
- #tags(options = {}) ⇒ Tag::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#initialize(options = {}) ⇒ Resource
constructor
A new instance of Resource.
Constructor Details
Instance Method Details
#activities(options = {}) ⇒ Activity::Collection
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
activities = auto_scaling.activities({
activity_ids: ["XmlString"],
auto_scaling_group_name: "XmlStringMaxLen255",
include_deleted_groups: false,
filters: [
{
name: "XmlString",
values: ["XmlString"],
},
],
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:activity_ids
(Array<String>)
—
The activity IDs of the desired scaling activities. If unknown activity IDs are requested, they are ignored with no error. Only activities started within the last six weeks can be returned regardless of the activity IDs specified. If other filters are specified with the request, only results matching all filter criteria can be returned.
Array Members: Maximum number of 50 IDs.
-
:auto_scaling_group_name
(String)
—
The name of the Auto Scaling group.
Omitting this property performs an account-wide operation, which can result in slower or timed-out requests.
-
:include_deleted_groups
(Boolean)
—
Indicates whether to include scaling activity from deleted Auto Scaling groups.
-
:filters
(Array<Types::Filter>)
—
One or more filters to limit the results based on specific criteria. The following filters are supported:
-
StartTimeLowerBound- The earliest scaling activities to return based on the activity start time. Scaling activities with a start time earlier than this value are not included in the results. Only activities started within the last six weeks can be returned regardless of the value specified. -
StartTimeUpperBound- The latest scaling activities to return based on the activity start time. Scaling activities with a start time later than this value are not included in the results. Only activities started within the last six weeks can be returned regardless of the value specified. -
Status- TheStatusCodevalue of the scaling activity. This filter can only be used in combination with theAutoScalingGroupNameparameter. For validStatusCodevalues, see Activity in the Amazon EC2 Auto Scaling API Reference.
StartTimeLowerBoundandStartTimeUpperBoundaccept ISO 8601 formatted timestamps. Timestamps without a timezone offset are assumed to be UTC.-
2000-01-18T08:15:00Z -
2000-01-18T16:15:00+08:00
-
Returns:
305 |
# File 'sig/resource.rbs', line 305
def activities: (
|
#activity(id) ⇒ Activity
319 |
# File 'sig/resource.rbs', line 319
def activity: (String id) -> Activity
|
#client ⇒ Client
Returns:
- (Client)
32 |
# File 'lib/aws-sdk-autoscaling/resource.rb', line 32
def client: () -> Client
|
#create_group(options = {}) ⇒ AutoScalingGroup
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
autoscalinggroup = auto_scaling.create_group({
auto_scaling_group_name: "XmlStringMaxLen255", # required
launch_configuration_name: "XmlStringMaxLen255",
launch_template: {
launch_template_id: "XmlStringMaxLen255",
launch_template_name: "LaunchTemplateName",
version: "XmlStringMaxLen255",
},
mixed_instances_policy: {
launch_template: {
launch_template_specification: {
launch_template_id: "XmlStringMaxLen255",
launch_template_name: "LaunchTemplateName",
version: "XmlStringMaxLen255",
},
overrides: [
{
instance_type: "XmlStringMaxLen255",
weighted_capacity: "XmlStringMaxLen32",
launch_template_specification: {
launch_template_id: "XmlStringMaxLen255",
launch_template_name: "LaunchTemplateName",
version: "XmlStringMaxLen255",
},
instance_requirements: {
v_cpu_count: { # required
min: 1, # required
max: 1,
},
memory_mi_b: { # required
min: 1, # required
max: 1,
},
cpu_manufacturers: ["intel"], # accepts intel, amd, amazon-web-services, apple
memory_gi_b_per_v_cpu: {
min: 1.0,
max: 1.0,
},
excluded_instance_types: ["ExcludedInstance"],
instance_generations: ["current"], # accepts current, previous
spot_max_price_percentage_over_lowest_price: 1,
max_spot_price_as_percentage_of_optimal_on_demand_price: 1,
on_demand_max_price_percentage_over_lowest_price: 1,
bare_metal: "included", # accepts included, excluded, required
burstable_performance: "included", # accepts included, excluded, required
require_hibernate_support: false,
network_interface_count: {
min: 1,
max: 1,
},
local_storage: "included", # accepts included, excluded, required
local_storage_types: ["hdd"], # accepts hdd, ssd
total_local_storage_gb: {
min: 1.0,
max: 1.0,
},
baseline_ebs_bandwidth_mbps: {
min: 1,
max: 1,
},
accelerator_types: ["gpu"], # accepts gpu, fpga, inference
accelerator_count: {
min: 1,
max: 1,
},
accelerator_manufacturers: ["nvidia"], # accepts nvidia, amd, amazon-web-services, xilinx
accelerator_names: ["a100"], # accepts a100, v100, k80, t4, m60, radeon-pro-v520, vu9p
accelerator_total_memory_mi_b: {
min: 1,
max: 1,
},
network_bandwidth_gbps: {
min: 1.0,
max: 1.0,
},
allowed_instance_types: ["AllowedInstanceType"],
baseline_performance_factors: {
cpu: {
references: [
{
instance_family: "String",
},
],
},
},
},
image_id: "ImageId",
},
],
},
instances_distribution: {
on_demand_allocation_strategy: "XmlString",
on_demand_base_capacity: 1,
on_demand_percentage_above_base_capacity: 1,
spot_allocation_strategy: "XmlString",
spot_instance_pools: 1,
spot_max_price: "MixedInstanceSpotPrice",
},
},
instance_id: "XmlStringMaxLen19",
min_size: 1, # required
max_size: 1, # required
desired_capacity: 1,
default_cooldown: 1,
availability_zones: ["XmlStringMaxLen255"],
availability_zone_ids: ["XmlStringMaxLen255"],
load_balancer_names: ["XmlStringMaxLen255"],
target_group_arns: ["XmlStringMaxLen511"],
health_check_type: "XmlStringMaxLen32",
health_check_grace_period: 1,
placement_group: "XmlStringMaxLen255",
vpc_zone_identifier: "XmlStringMaxLen5000",
termination_policies: ["XmlStringMaxLen1600"],
new_instances_protected_from_scale_in: false,
capacity_rebalance: false,
lifecycle_hook_specification_list: [
{
lifecycle_hook_name: "AsciiStringMaxLen255", # required
lifecycle_transition: "LifecycleTransition", # required
notification_metadata: "AnyPrintableAsciiStringMaxLen4000",
heartbeat_timeout: 1,
default_result: "LifecycleActionResult",
notification_target_arn: "NotificationTargetResourceName",
role_arn: "XmlStringMaxLen255",
},
],
deletion_protection: "none", # accepts none, prevent-force-deletion, prevent-all-deletion
tags: [
{
resource_id: "XmlString",
resource_type: "XmlString",
key: "TagKey", # required
value: "TagValue",
propagate_at_launch: false,
},
],
service_linked_role_arn: "ResourceName",
max_instance_lifetime: 1,
context: "Context",
desired_capacity_type: "XmlStringMaxLen255",
default_instance_warmup: 1,
traffic_sources: [
{
identifier: "XmlStringMaxLen511", # required
type: "XmlStringMaxLen511",
},
],
instance_maintenance_policy: {
min_healthy_percentage: 1,
max_healthy_percentage: 1,
},
availability_zone_distribution: {
capacity_distribution_strategy: "balanced-only", # accepts balanced-only, balanced-best-effort, reservations-then-balanced
},
availability_zone_impairment_policy: {
zonal_shift_enabled: false,
impaired_zone_health_check_behavior: "ReplaceUnhealthy", # accepts ReplaceUnhealthy, IgnoreUnhealthy
},
skip_zonal_shift_validation: false,
capacity_reservation_specification: {
capacity_reservation_preference: "capacity-reservations-only", # accepts capacity-reservations-only, capacity-reservations-first, none, default
capacity_reservation_target: {
capacity_reservation_ids: ["AsciiStringMaxLen255"],
capacity_reservation_resource_group_arns: ["ResourceName"],
},
},
instance_lifecycle_policy: {
retention_triggers: {
terminate_hook_abandon: "retain", # accepts retain, terminate
},
},
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:auto_scaling_group_name
(required, String)
—
The name of the Auto Scaling group. This name must be unique per Region per account.
The name can contain any ASCII character 33 to 126 including most punctuation characters, digits, and upper and lowercased letters.
You cannot use a colon (:) in the name. -
:launch_configuration_name
(String)
—
The name of the launch configuration to use to launch instances.
Conditional: You must specify either a launch template (
LaunchTemplateorMixedInstancesPolicy) or a launch configuration (LaunchConfigurationNameorInstanceId). -
:launch_template
(Types::LaunchTemplateSpecification)
—
Information used to specify the launch template and version to use to launch instances.
Conditional: You must specify either a launch template (
LaunchTemplateorMixedInstancesPolicy) or a launch configuration (LaunchConfigurationNameorInstanceId).The launch template that is specified must be configured for use with an Auto Scaling group. For more information, see Create a launch template for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide. -
:mixed_instances_policy
(Types::MixedInstancesPolicy)
—
The mixed instances policy. For more information, see Auto Scaling groups with multiple instance types and purchase options in the Amazon EC2 Auto Scaling User Guide.
-
:instance_id
(String)
—
The ID of the instance used to base the launch configuration on. If specified, Amazon EC2 Auto Scaling uses the configuration values from the specified instance to create a new launch configuration. To get the instance ID, use the Amazon EC2 DescribeInstances API operation. For more information, see Create an Auto Scaling group using parameters from an existing instance in the Amazon EC2 Auto Scaling User Guide.
-
:min_size
(required, Integer)
—
The minimum size of the group.
-
:max_size
(required, Integer)
—
The maximum size of the group.
With a mixed instances policy that uses instance weighting, Amazon EC2 Auto Scaling may need to go above MaxSizeto meet your capacity requirements. In this event, Amazon EC2 Auto Scaling will never go aboveMaxSizeby more than your largest instance weight (weights that define how many units each instance contributes to the desired capacity of the group). -
:desired_capacity
(Integer)
—
The desired capacity is the initial capacity of the Auto Scaling group at the time of its creation and the capacity it attempts to maintain. It can scale beyond this capacity if you configure auto scaling. This number must be greater than or equal to the minimum size of the group and less than or equal to the maximum size of the group. If you do not specify a desired capacity, the default is the minimum size of the group.
-
:default_cooldown
(Integer)
—
Only needed if you use simple scaling policies.
The amount of time, in seconds, between one scaling activity ending and another one starting due to simple scaling policies. For more information, see Scaling cooldowns for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.
Default:
300seconds -
:availability_zones
(Array<String>)
—
A list of Availability Zones where instances in the Auto Scaling group can be created. Used for launching into the default VPC subnet in each Availability Zone when not using the
VPCZoneIdentifierproperty, or for attaching a network interface when an existing network interface ID is specified in a launch template. -
:availability_zone_ids
(Array<String>)
—
A list of Availability Zone IDs where the Auto Scaling group can launch instances. You cannot specify both AvailabilityZones and AvailabilityZoneIds in the same request.
-
:load_balancer_names
(Array<String>)
—
A list of Classic Load Balancers associated with this Auto Scaling group. For Application Load Balancers, Network Load Balancers, and Gateway Load Balancers, specify the
TargetGroupARNsproperty instead. -
:target_group_arns
(Array<String>)
—
The Amazon Resource Names (ARN) of the Elastic Load Balancing target groups to associate with the Auto Scaling group. Instances are registered as targets with the target groups. The target groups receive incoming traffic and route requests to one or more registered targets. For more information, see Use Elastic Load Balancing to distribute traffic across the instances in your Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.
-
:health_check_type
(String)
—
A comma-separated value string of one or more health check types.
The valid values are
EC2,EBS,ELB, andVPC_LATTICE.EC2is the default health check and cannot be disabled. For more information, see Health checks for instances in an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.Only specify
EC2if you must clear a value that was previously set. -
:health_check_grace_period
(Integer)
—
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits before checking the health status of an EC2 instance that has come into service and marking it unhealthy due to a failed health check. This is useful if your instances do not immediately pass their health checks after they enter the
InServicestate. For more information, see Set the health check grace period for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.Default:
0seconds -
:placement_group
(String)
—
The name of the placement group into which to launch your instances. For more information, see Placement groups in the Amazon EC2 User Guide.
A cluster placement group is a logical grouping of instances within a single Availability Zone. You cannot specify multiple Availability Zones and a cluster placement group. -
:vpc_zone_identifier
(String)
—
A comma-separated list of subnet IDs for a virtual private cloud (VPC) where instances in the Auto Scaling group can be created. If you specify
VPCZoneIdentifierwithAvailabilityZones, the subnets that you specify must reside in those Availability Zones. -
:termination_policies
(Array<String>)
—
A policy or a list of policies that are used to select the instance to terminate. These policies are executed in the order that you list them. For more information, see Configure termination policies for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.
Valid values:
Default|AllocationStrategy|ClosestToNextInstanceHour|NewestInstance|OldestInstance|OldestLaunchConfiguration|OldestLaunchTemplate|arn:aws:lambda:region:account-id:function:my-function:my-alias -
:new_instances_protected_from_scale_in
(Boolean)
—
Indicates whether newly launched instances are protected from termination by Amazon EC2 Auto Scaling when scaling in. For more information about preventing instances from terminating on scale in, see Use instance scale-in protection in the Amazon EC2 Auto Scaling User Guide.
-
:capacity_rebalance
(Boolean)
—
Indicates whether Capacity Rebalancing is enabled. Otherwise, Capacity Rebalancing is disabled. When you turn on Capacity Rebalancing, Amazon EC2 Auto Scaling attempts to launch a Spot Instance whenever Amazon EC2 notifies that a Spot Instance is at an elevated risk of interruption. After launching a new instance, it then terminates an old instance. For more information, see Use Capacity Rebalancing to handle Amazon EC2 Spot Interruptions in the in the Amazon EC2 Auto Scaling User Guide.
-
:lifecycle_hook_specification_list
(Array<Types::LifecycleHookSpecification>)
—
One or more lifecycle hooks to add to the Auto Scaling group before instances are launched.
-
:deletion_protection
(String)
—
The deletion protection setting for the Auto Scaling group. This setting helps safeguard your Auto Scaling group and its instances by controlling whether the
DeleteAutoScalingGroupoperation is allowed. When deletion protection is enabled, users cannot delete the Auto Scaling group according to the specified protection level until the setting is changed back to a less restrictive level.The valid values are
none,prevent-force-deletion, andprevent-all-deletion.Default:
noneFor more information, see Configure deletion protection for your Amazon EC2 Auto Scaling resources in the Amazon EC2 Auto Scaling User Guide.
-
:tags
(Array<Types::Tag>)
—
One or more tags. You can tag your Auto Scaling group and propagate the tags to the Amazon EC2 instances it launches. Tags are not propagated to Amazon EBS volumes. To add tags to Amazon EBS volumes, specify the tags in a launch template but use caution. If the launch template specifies an instance tag with a key that is also specified for the Auto Scaling group, Amazon EC2 Auto Scaling overrides the value of that instance tag with the value specified by the Auto Scaling group. For more information, see Tag Auto Scaling groups and instances in the Amazon EC2 Auto Scaling User Guide.
-
:service_linked_role_arn
(String)
—
The Amazon Resource Name (ARN) of the service-linked role that the Auto Scaling group uses to call other Amazon Web Services service on your behalf. By default, Amazon EC2 Auto Scaling uses a service-linked role named
AWSServiceRoleForAutoScaling, which it creates if it does not exist. For more information, see Service-linked roles in the Amazon EC2 Auto Scaling User Guide. -
:max_instance_lifetime
(Integer)
—
The maximum amount of time, in seconds, that an instance can be in service. The default is null. If specified, the value must be either 0 or a number equal to or greater than 86,400 seconds (1 day). For more information, see Replace Auto Scaling instances based on maximum instance lifetime in the Amazon EC2 Auto Scaling User Guide.
-
:context
(String)
—
Reserved.
-
:desired_capacity_type
(String)
—
The unit of measurement for the value specified for desired capacity. Amazon EC2 Auto Scaling supports
DesiredCapacityTypefor attribute-based instance type selection only. For more information, see Create a mixed instances group using attribute-based instance type selection in the Amazon EC2 Auto Scaling User Guide.By default, Amazon EC2 Auto Scaling specifies
units, which translates into number of instances.Valid values:
units|vcpu|memory-mib -
:default_instance_warmup
(Integer)
—
The amount of time, in seconds, until a new instance is considered to have finished initializing and resource consumption to become stable after it enters the
InServicestate.During an instance refresh, Amazon EC2 Auto Scaling waits for the warm-up period after it replaces an instance before it moves on to replacing the next instance. Amazon EC2 Auto Scaling also waits for the warm-up period before aggregating the metrics for new instances with existing instances in the Amazon CloudWatch metrics that are used for scaling, resulting in more reliable usage data. For more information, see Set the default instance warmup for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.
To manage various warm-up settings at the group level, we recommend that you set the default instance warmup, even if it is set to 0 seconds. To remove a value that you previously set, include the property but specify
-1for the value. However, we strongly recommend keeping the default instance warmup enabled by specifying a value of0or other nominal value.Default: None
-
:traffic_sources
(Array<Types::TrafficSourceIdentifier>)
—
The list of traffic sources to attach to this Auto Scaling group. You can use any of the following as traffic sources for an Auto Scaling group: Classic Load Balancer, Application Load Balancer, Gateway Load Balancer, Network Load Balancer, and VPC Lattice.
-
:instance_maintenance_policy
(Types::InstanceMaintenancePolicy)
—
An instance maintenance policy. For more information, see Set instance maintenance policy in the Amazon EC2 Auto Scaling User Guide.
-
:availability_zone_distribution
(Types::AvailabilityZoneDistribution)
—
The instance capacity distribution across Availability Zones.
-
:availability_zone_impairment_policy
(Types::AvailabilityZoneImpairmentPolicy)
—
The policy for Availability Zone impairment.
-
:skip_zonal_shift_validation
(Boolean)
—
If you enable zonal shift with cross-zone disabled load balancers, capacity could become imbalanced across Availability Zones. To skip the validation, specify
true. For more information, see Auto Scaling group zonal shift in the Amazon EC2 Auto Scaling User Guide. -
:capacity_reservation_specification
(Types::CapacityReservationSpecification)
—
The capacity reservation specification for the Auto Scaling group.
-
:instance_lifecycle_policy
(Types::InstanceLifecyclePolicy)
—
The instance lifecycle policy for the Auto Scaling group. This policy controls instance behavior when an instance transitions through its lifecycle states. Configure retention triggers to specify when instances should move to a
Retainedstate instead of automatic termination.For more information, see Control instance retention with instance lifecycle policies in the Amazon EC2 Auto Scaling User Guide.
Instances in a Retained state will continue to incur standard EC2 charges until terminated.
Returns:
84 |
# File 'sig/resource.rbs', line 84
def create_group: (
|
#create_launch_configuration(options = {}) ⇒ LaunchConfiguration
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
launchconfiguration = auto_scaling.create_launch_configuration({
launch_configuration_name: "XmlStringMaxLen255", # required
image_id: "XmlStringMaxLen255",
key_name: "XmlStringMaxLen255",
security_groups: ["XmlString"],
classic_link_vpc_id: "XmlStringMaxLen255",
classic_link_vpc_security_groups: ["XmlStringMaxLen255"],
user_data: "XmlStringUserData",
instance_id: "XmlStringMaxLen19",
instance_type: "XmlStringMaxLen255",
kernel_id: "XmlStringMaxLen255",
ramdisk_id: "XmlStringMaxLen255",
block_device_mappings: [
{
virtual_name: "XmlStringMaxLen255",
device_name: "XmlStringMaxLen255", # required
ebs: {
snapshot_id: "XmlStringMaxLen255",
volume_size: 1,
volume_type: "BlockDeviceEbsVolumeType",
delete_on_termination: false,
iops: 1,
encrypted: false,
throughput: 1,
},
no_device: false,
},
],
instance_monitoring: {
enabled: false,
},
spot_price: "SpotPrice",
iam_instance_profile: "XmlStringMaxLen1600",
ebs_optimized: false,
associate_public_ip_address: false,
placement_tenancy: "XmlStringMaxLen64",
metadata_options: {
http_tokens: "optional", # accepts optional, required
http_put_response_hop_limit: 1,
http_endpoint: "disabled", # accepts disabled, enabled
},
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:launch_configuration_name
(required, String)
—
The name of the launch configuration. This name must be unique per Region per account.
-
:image_id
(String)
—
The ID of the Amazon Machine Image (AMI) that was assigned during registration. For more information, see Find a Linux AMI in the Amazon EC2 User Guide.
If you specify
InstanceId, anImageIdis not required. -
:key_name
(String)
—
The name of the key pair. For more information, see Amazon EC2 key pairs and Amazon EC2 instances in the Amazon EC2 User Guide.
-
:security_groups
(Array<String>)
—
A list that contains the security group IDs to assign to the instances in the Auto Scaling group. For more information, see Control traffic to your Amazon Web Services resources using security groups in the Amazon Virtual Private Cloud User Guide.
-
:classic_link_vpc_id
(String)
—
Available for backward compatibility.
-
:classic_link_vpc_security_groups
(Array<String>)
—
Available for backward compatibility.
-
:user_data
(String)
—
The user data to make available to the launched EC2 instances. For more information, see Instance metadata and user data (Linux) and Instance metadata and user data (Windows). If you are using a command line tool, base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide base64-encoded text. User data is limited to 16 KB.
-
:instance_id
(String)
—
The ID of the instance to use to create the launch configuration. The new launch configuration derives attributes from the instance, except for the block device mapping.
To create a launch configuration with a block device mapping or override any other instance attributes, specify them as part of the same request.
For more information, see Create a launch configuration in the Amazon EC2 Auto Scaling User Guide.
-
:instance_type
(String)
—
Specifies the instance type of the EC2 instance. For information about available instance types, see Available instance types in the Amazon EC2 User Guide.
If you specify
InstanceId, anInstanceTypeis not required. -
:kernel_id
(String)
—
The ID of the kernel associated with the AMI.
We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see User provided kernels in the Amazon EC2 User Guide. -
:ramdisk_id
(String)
—
The ID of the RAM disk to select.
We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see User provided kernels in the Amazon EC2 User Guide. -
:block_device_mappings
(Array<Types::BlockDeviceMapping>)
—
The block device mapping entries that define the block devices to attach to the instances at launch. By default, the block devices specified in the block device mapping for the AMI are used. For more information, see Block device mappings in the Amazon EC2 User Guide.
-
:instance_monitoring
(Types::InstanceMonitoring)
—
Controls whether instances in this group are launched with detailed (
true) or basic (false) monitoring.The default value is
true(enabled).When detailed monitoring is enabled, Amazon CloudWatch generates metrics every minute and your account is charged a fee. When you disable detailed monitoring, CloudWatch generates metrics every 5 minutes. For more information, see Configure monitoring for Auto Scaling instances in the Amazon EC2 Auto Scaling User Guide.
-
:spot_price
(String)
—
The maximum hourly price to be paid for any Spot Instance launched to fulfill the request. Spot Instances are launched when the price you specify exceeds the current Spot price. For more information, see Request Spot Instances for fault-tolerant and flexible applications in the Amazon EC2 Auto Scaling User Guide.
Valid Range: Minimum value of 0.001
When you change your maximum price by creating a new launch configuration, running instances will continue to run as long as the maximum price for those running instances is higher than the current Spot price. -
:iam_instance_profile
(String)
—
The name or the Amazon Resource Name (ARN) of the instance profile associated with the IAM role for the instance. The instance profile contains the IAM role. For more information, see IAM role for applications that run on Amazon EC2 instances in the Amazon EC2 Auto Scaling User Guide.
-
:ebs_optimized
(Boolean)
—
Specifies whether the launch configuration is optimized for EBS I/O (
true) or not (false). The optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization is not available with all instance types. Additional fees are incurred when you enable EBS optimization for an instance type that is not EBS-optimized by default. For more information, see Amazon EBS-optimized instances in the Amazon EC2 User Guide.The default value is
false. -
:associate_public_ip_address
(Boolean)
—
Specifies whether to assign a public IPv4 address to the group's instances. If the instance is launched into a default subnet, the default is to assign a public IPv4 address, unless you disabled the option to assign a public IPv4 address on the subnet. If the instance is launched into a nondefault subnet, the default is not to assign a public IPv4 address, unless you enabled the option to assign a public IPv4 address on the subnet.
If you specify
true, each instance in the Auto Scaling group receives a unique public IPv4 address. For more information, see Provide network connectivity for your Auto Scaling instances using Amazon VPC in the Amazon EC2 Auto Scaling User Guide.If you specify this property, you must specify at least one subnet for
VPCZoneIdentifierwhen you create your group. -
:placement_tenancy
(String)
—
The tenancy of the instance, either
defaultordedicated. An instance withdedicatedtenancy runs on isolated, single-tenant hardware and can only be launched into a VPC. To launch dedicated instances into a shared tenancy VPC (a VPC with the instance placement tenancy attribute set todefault), you must set the value of this property todedicated.If you specify
PlacementTenancy, you must specify at least one subnet forVPCZoneIdentifierwhen you create your group.Valid values:
default|dedicated -
:metadata_options
(Types::InstanceMetadataOptions)
—
The metadata options for the instances. For more information, see Configure the instance metadata options in the Amazon EC2 Auto Scaling User Guide.
Returns:
259 |
# File 'sig/resource.rbs', line 259
def create_launch_configuration: (
|
#group(name) ⇒ AutoScalingGroup
322 |
# File 'sig/resource.rbs', line 322
def group: (String name) -> AutoScalingGroup
|
#groups(options = {}) ⇒ AutoScalingGroup::Collection
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
groups = auto_scaling.groups({
auto_scaling_group_names: ["XmlStringMaxLen255"],
include_instances: false,
filters: [
{
name: "XmlString",
values: ["XmlString"],
},
],
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:auto_scaling_group_names
(Array<String>)
—
The names of the Auto Scaling groups. By default, you can only specify up to 50 names. You can optionally increase this limit using the
MaxRecordsproperty.If you omit this property, all Auto Scaling groups are described.
-
:include_instances
(Boolean)
—
Specifies whether to include information about Amazon EC2 instances in the response. When set to
true(default), the response includes instance details. -
:filters
(Array<Types::Filter>)
—
One or more filters to limit the results based on specific tags.
Returns:
325 |
# File 'sig/resource.rbs', line 325
def groups: (
|
#instances(options = {}) ⇒ Instance::Collection
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
instances = auto_scaling.instances({
instance_ids: ["XmlStringMaxLen19"],
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:instance_ids
(Array<String>)
—
The IDs of the instances. If you omit this property, all Auto Scaling instances are described. If you specify an ID that does not exist, it is ignored with no error.
Array Members: Maximum number of 50 items.
Returns:
338 |
# File 'sig/resource.rbs', line 338
def instances: (
|
#launch_configuration(name) ⇒ LaunchConfiguration
344 |
# File 'sig/resource.rbs', line 344
def launch_configuration: (String name) -> LaunchConfiguration
|
#launch_configurations(options = {}) ⇒ LaunchConfiguration::Collection
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
launch_configurations = auto_scaling.launch_configurations({
launch_configuration_names: ["XmlStringMaxLen255"],
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:launch_configuration_names
(Array<String>)
—
The launch configuration names. If you omit this property, all launch configurations are described.
Array Members: Maximum number of 50 items.
Returns:
347 |
# File 'sig/resource.rbs', line 347
def launch_configurations: (
|
#policies(options = {}) ⇒ ScalingPolicy::Collection
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
policies = auto_scaling.policies({
auto_scaling_group_name: "XmlStringMaxLen255",
policy_names: ["ResourceName"],
policy_types: ["XmlStringMaxLen64"],
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:auto_scaling_group_name
(String)
—
The name of the Auto Scaling group.
-
:policy_names
(Array<String>)
—
The names of one or more policies. If you omit this property, all policies are described. If a group name is provided, the results are limited to that group. If you specify an unknown policy name, it is ignored with no error.
Array Members: Maximum number of 50 items.
-
:policy_types
(Array<String>)
—
One or more policy types. The valid values are
SimpleScaling,StepScaling,TargetTrackingScaling, andPredictiveScaling.
Returns:
353 |
# File 'sig/resource.rbs', line 353
def policies: (
|
#policy(name) ⇒ ScalingPolicy
361 |
# File 'sig/resource.rbs', line 361
def policy: (String name) -> ScalingPolicy
|
#scheduled_action(name) ⇒ ScheduledAction
364 |
# File 'sig/resource.rbs', line 364
def scheduled_action: (String name) -> ScheduledAction
|
#scheduled_actions(options = {}) ⇒ ScheduledAction::Collection
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
scheduled_actions = auto_scaling.scheduled_actions({
auto_scaling_group_name: "XmlStringMaxLen255",
scheduled_action_names: ["XmlStringMaxLen255"],
start_time: Time.now,
end_time: Time.now,
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:auto_scaling_group_name
(String)
—
The name of the Auto Scaling group.
-
:scheduled_action_names
(Array<String>)
—
The names of one or more scheduled actions. If you omit this property, all scheduled actions are described. If you specify an unknown scheduled action, it is ignored with no error.
Array Members: Maximum number of 50 actions.
-
:start_time
(Time, DateTime, Date, Integer, String)
—
The earliest scheduled start time to return. If scheduled action names are provided, this property is ignored.
-
:end_time
(Time, DateTime, Date, Integer, String)
—
The latest scheduled start time to return. If scheduled action names are provided, this property is ignored.
Returns:
367 |
# File 'sig/resource.rbs', line 367
def scheduled_actions: (
|
#tags(options = {}) ⇒ Tag::Collection
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
tags = auto_scaling.tags({
filters: [
{
name: "XmlString",
values: ["XmlString"],
},
],
})
Parameters:
-
options
(Hash)
(defaults to: {})
—
({})
Options Hash (options):
-
:filters
(Array<Types::Filter>)
—
One or more filters to scope the tags to return. The maximum number of filters per filter type (for example,
auto-scaling-group) is 1000.
Returns:
376 |
# File 'sig/resource.rbs', line 376
def tags: (
|