Class: Aws::AutoScaling::ScheduledAction

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/scheduled_action.rbs,
lib/aws-sdk-autoscaling/scheduled_action.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ ScheduledAction #initialize(options = {}) ⇒ ScheduledAction

Returns a new instance of ScheduledAction.

Overloads:

  • #initialize(name, options = {}) ⇒ ScheduledAction

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ ScheduledAction

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/scheduled_action.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#auto_scaling_group_nameString

The name of the Auto Scaling group.

Returns:

  • (String)


22
# File 'sig/scheduled_action.rbs', line 22

def auto_scaling_group_name: () -> ::String

#clientClient

Returns:



108
# File 'lib/aws-sdk-autoscaling/scheduled_action.rb', line 108

def client: () -> Client

#dataTypes::ScheduledUpdateGroupAction



58
# File 'sig/scheduled_action.rbs', line 58

def data: () -> Types::ScheduledUpdateGroupAction

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



61
# File 'sig/scheduled_action.rbs', line 61

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


scheduled_action.delete({
  auto_scaling_group_name: "XmlStringMaxLen255", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :auto_scaling_group_name (required, String)

    The name of the Auto Scaling group.

Returns:

  • (EmptyStructure)


65
# File 'sig/scheduled_action.rbs', line 65

def delete: (

#desired_capacityInteger

The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.

Returns:

  • (Integer)


46
# File 'sig/scheduled_action.rbs', line 46

def desired_capacity: () -> ::Integer

#end_timeTime

The date and time in UTC for the recurring schedule to end. For example, "2019-06-01T00:00:00Z".

Returns:

  • (Time)


34
# File 'sig/scheduled_action.rbs', line 34

def end_time: () -> ::Time

#groupAutoScalingGroup?

Returns:



71
# File 'sig/scheduled_action.rbs', line 71

def group: () -> AutoScalingGroup?

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


276
277
278
# File 'lib/aws-sdk-autoscaling/scheduled_action.rb', line 276

def identifiers
  { name: @name }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::AutoScaling::ScheduledAction. Returns self making it possible to chain methods.

scheduled_action.reload.data

Returns:

  • (self)


54
# File 'sig/scheduled_action.rbs', line 54

def load: () -> self

#max_sizeInteger

The maximum size of the Auto Scaling group.

Returns:

  • (Integer)


43
# File 'sig/scheduled_action.rbs', line 43

def max_size: () -> ::Integer

#min_sizeInteger

The minimum size of the Auto Scaling group.

Returns:

  • (Integer)


40
# File 'sig/scheduled_action.rbs', line 40

def min_size: () -> ::Integer

#nameString Also known as: scheduled_action_name

Returns:

  • (String)


18
# File 'sig/scheduled_action.rbs', line 18

def name: () -> String

#recurrenceString

The recurring schedule for the action, in Unix cron syntax format.

When StartTime and EndTime are specified with Recurrence, they form the boundaries of when the recurring action starts and stops.

Returns:

  • (String)


37
# File 'sig/scheduled_action.rbs', line 37

def recurrence: () -> ::String

#scheduled_action_arnString

The Amazon Resource Name (ARN) of the scheduled action.

Returns:

  • (String)


25
# File 'sig/scheduled_action.rbs', line 25

def scheduled_action_arn: () -> ::String

#start_timeTime

The date and time in UTC for this action to start. For example, "2019-06-01T00:00:00Z".

Returns:

  • (Time)


31
# File 'sig/scheduled_action.rbs', line 31

def start_time: () -> ::Time

#timeTime

This property is no longer used.

Returns:

  • (Time)


28
# File 'sig/scheduled_action.rbs', line 28

def time: () -> ::Time

#time_zoneString

The time zone for the cron expression.

Returns:

  • (String)


49
# File 'sig/scheduled_action.rbs', line 49

def time_zone: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::AutoScaling::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/aws-sdk-autoscaling/scheduled_action.rb', line 222

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end