Class: Aws::AutoScaling::Tag

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/tag.rbs,
lib/aws-sdk-autoscaling/tag.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(key, resource_id, resource_type, options = {}) ⇒ Tag #initialize(options = {}) ⇒ Tag

Returns a new instance of Tag.

Overloads:

  • #initialize(key, resource_id, resource_type, options = {}) ⇒ Tag

    Parameters:

    • key (String)
    • resource_id (String)
    • resource_type (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Tag

    Options Hash (options):

    • :key (required, String)
    • :resource_id (required, String)
    • :resource_type (required, String)
    • :client (Client)


13
14
15
# File 'sig/tag.rbs', line 13

def initialize: (String key, String resource_id, String resource_type, Hash[Symbol, untyped] options) -> void
| (key: String, resource_id: String, resource_type: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



69
# File 'lib/aws-sdk-autoscaling/tag.rb', line 69

def client: () -> Client

#create(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


tag.create({
  tags: [ # required
    {
      resource_id: "XmlString",
      resource_type: "XmlString",
      key: "TagKey", # required
      value: "TagValue",
      propagate_at_launch: false,
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :tags (required, Array<Types::Tag>)

    One or more tags.

Returns:

  • (EmptyStructure)


46
# File 'sig/tag.rbs', line 46

def create: (

#dataTypes::TagDescription

Returns the data for this Aws::AutoScaling::Tag. Calls Client#describe_tags if #data_loaded? is false.

Returns:



39
# File 'sig/tag.rbs', line 39

def data: () -> Types::TagDescription

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



42
# File 'sig/tag.rbs', line 42

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


tag.delete({
  tags: [ # required
    {
      resource_id: "XmlString",
      resource_type: "XmlString",
      key: "TagKey", # required
      value: "TagValue",
      propagate_at_launch: false,
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :tags (required, Array<Types::Tag>)

    One or more tags.

Returns:

  • (EmptyStructure)


60
# File 'sig/tag.rbs', line 60

def delete: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


273
274
275
276
277
278
279
# File 'lib/aws-sdk-autoscaling/tag.rb', line 273

def identifiers
  {
    key: @key,
    resource_id: @resource_id,
    resource_type: @resource_type
  }
end

#keyString

Returns:

  • (String)


18
# File 'sig/tag.rbs', line 18

def key: () -> String

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::AutoScaling::Tag. Returns self making it possible to chain methods.

tag.reload.data

Returns:

  • (self)


35
# File 'sig/tag.rbs', line 35

def load: () -> self

#propagate_at_launchBoolean

Determines whether the tag is added to new instances as they are launched in the group.

Returns:

  • (Boolean)


30
# File 'sig/tag.rbs', line 30

def propagate_at_launch: () -> bool

#resource_idString

Returns:

  • (String)


21
# File 'sig/tag.rbs', line 21

def resource_id: () -> String

#resource_typeString

Returns:

  • (String)


24
# File 'sig/tag.rbs', line 24

def resource_type: () -> String

#valueString

The tag value.

Returns:

  • (String)


27
# File 'sig/tag.rbs', line 27

def value: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::AutoScaling::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-autoscaling/tag.rb', line 192

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end