Class: Aws::AutoScaling::Types::AttachTrafficSourcesType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_nameString

The name of the Auto Scaling group.

Returns:

  • (String)


347
348
349
350
351
352
353
# File 'lib/aws-sdk-autoscaling/types.rb', line 347

class AttachTrafficSourcesType < Struct.new(
  :auto_scaling_group_name,
  :traffic_sources,
  :skip_zonal_shift_validation)
  SENSITIVE = []
  include Aws::Structure
end

#skip_zonal_shift_validationBoolean

If you enable zonal shift with cross-zone disabled load balancers, capacity could become imbalanced across Availability Zones. To skip the validation, specify true. For more information, see Auto Scaling group zonal shift in the Amazon EC2 Auto Scaling User Guide.

Returns:

  • (Boolean)


347
348
349
350
351
352
353
# File 'lib/aws-sdk-autoscaling/types.rb', line 347

class AttachTrafficSourcesType < Struct.new(
  :auto_scaling_group_name,
  :traffic_sources,
  :skip_zonal_shift_validation)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_sourcesArray<Types::TrafficSourceIdentifier>

The unique identifiers of one or more traffic sources. You can specify up to 10 traffic sources.

Returns:



347
348
349
350
351
352
353
# File 'lib/aws-sdk-autoscaling/types.rb', line 347

class AttachTrafficSourcesType < Struct.new(
  :auto_scaling_group_name,
  :traffic_sources,
  :skip_zonal_shift_validation)
  SENSITIVE = []
  include Aws::Structure
end