Class: Aws::AutoScaling::Types::AutoScalingGroupsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::AutoScalingGroupsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_groups ⇒ Array<Types::AutoScalingGroup>
The groups.
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
Instance Attribute Details
#auto_scaling_groups ⇒ Array<Types::AutoScalingGroup>
The groups.
653 654 655 656 657 658 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 653 class AutoScalingGroupsType < Struct.new( :auto_scaling_groups, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
653 654 655 656 657 658 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 653 class AutoScalingGroupsType < Struct.new( :auto_scaling_groups, :next_token) SENSITIVE = [] include Aws::Structure end |