Class: Aws::AutoScaling::Types::AutoScalingInstanceDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Describes an EC2 instance associated with an Auto Scaling group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_nameString

The name of the Auto Scaling group for the instance.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone for the instance.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The Availability Zone ID where the instance is located.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#health_statusString

The last reported health status of this instance. ‘Healthy` means that the instance is healthy and should remain in service. `Unhealthy` means that the instance is unhealthy and Amazon EC2 Auto Scaling should terminate and replace it.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#image_idString

The ID of the Amazon Machine Image (AMI) associated with the instance. This field shows the current AMI ID of the instance’s root volume. It may differ from the original AMI used when the instance was first launched.

This field appears for:

  • Instances with root volume replacements through Instance Refresh

  • Instances launched with AMI overrides

This field won’t appear for:

  • Existing instances launched from Launch Templates without overrides

  • Existing instances that didn’t have their root volume replaced through Instance Refresh

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type of the EC2 instance.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#launch_configuration_nameString

The launch configuration used to launch the instance. This value is not available if you attached the instance to the Auto Scaling group.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#launch_templateTypes::LaunchTemplateSpecification

The launch template for the instance.



750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_stateString

The lifecycle state for the instance. The ‘Quarantined` state is not used. For more information, see [Amazon EC2 Auto Scaling instance lifecycle] in the *Amazon EC2 Auto Scaling User Guide*.

Valid values: ‘Pending` | `Pending:Wait` | `Pending:Proceed` | `Quarantined` | `InService` | `Terminating` | `Terminating:Wait` | `Terminating:Proceed` | `Terminating:Retained` | `Terminated` | `Detaching` | `Detached` | `EnteringStandby` | `Standby` | `ReplacingRootVolume` | `ReplacingRootVolume:Wait` | `ReplacingRootVolume:Proceed` | `RootVolumeReplaced` | `Warmed:Pending` | `Warmed:Pending:Wait` | `Warmed:Pending:Proceed` | `Warmed:Pending:Retained` | `Warmed:Terminating` | `Warmed:Terminating:Wait` | `Warmed:Terminating:Proceed` | `Warmed:Terminating:Retained` | `Warmed:Terminated` | `Warmed:Stopped` | `Warmed:Running` | `Warmed:Hibernated`

[1]: docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-lifecycle.html

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#protected_from_scale_inBoolean

Indicates whether the instance is protected from termination by Amazon EC2 Auto Scaling when scaling in.

Returns:

  • (Boolean)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end

#weighted_capacityString

The number of capacity units contributed by the instance based on its instance type.

Valid Range: Minimum value of 1. Maximum value of 999.

Returns:

  • (String)


750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
# File 'lib/aws-sdk-autoscaling/types.rb', line 750

class AutoScalingInstanceDetails < Struct.new(
  :instance_id,
  :instance_type,
  :auto_scaling_group_name,
  :availability_zone,
  :availability_zone_id,
  :lifecycle_state,
  :health_status,
  :launch_configuration_name,
  :launch_template,
  :image_id,
  :protected_from_scale_in,
  :weighted_capacity)
  SENSITIVE = []
  include Aws::Structure
end