Class: Aws::AutoScaling::Types::AutoScalingInstancesType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::AutoScalingInstancesType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_instances ⇒ Array<Types::AutoScalingInstanceDetails>
The instances.
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
Instance Attribute Details
#auto_scaling_instances ⇒ Array<Types::AutoScalingInstanceDetails>
The instances.
794 795 796 797 798 799 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 794 class AutoScalingInstancesType < Struct.new( :auto_scaling_instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
794 795 796 797 798 799 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 794 class AutoScalingInstancesType < Struct.new( :auto_scaling_instances, :next_token) SENSITIVE = [] include Aws::Structure end |