Class: Aws::AutoScaling::Types::CancelInstanceRefreshType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::CancelInstanceRefreshType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#wait_for_transitioning_instances ⇒ Boolean
When cancelling an instance refresh, this indicates whether to wait for in-flight launches and terminations to complete.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
1046 1047 1048 1049 1050 1051 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 1046 class CancelInstanceRefreshType < Struct.new( :auto_scaling_group_name, :wait_for_transitioning_instances) SENSITIVE = [] include Aws::Structure end |
#wait_for_transitioning_instances ⇒ Boolean
When cancelling an instance refresh, this indicates whether to wait for in-flight launches and terminations to complete. The default is true.
When set to false, Amazon EC2 Auto Scaling cancels the instance refresh without waiting for any pending launches or terminations to complete.
1046 1047 1048 1049 1050 1051 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 1046 class CancelInstanceRefreshType < Struct.new( :auto_scaling_group_name, :wait_for_transitioning_instances) SENSITIVE = [] include Aws::Structure end |