Class: Aws::AutoScaling::Types::CompleteLifecycleActionType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_nameString

The name of the Auto Scaling group.



1165
1166
1167
1168
1169
1170
1171
1172
1173
# File 'lib/aws-sdk-autoscaling/types.rb', line 1165

class CompleteLifecycleActionType < Struct.new(
  :lifecycle_hook_name,
  :auto_scaling_group_name,
  :lifecycle_action_token,
  :lifecycle_action_result,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

The ID of the instance.



1165
1166
1167
1168
1169
1170
1171
1172
1173
# File 'lib/aws-sdk-autoscaling/types.rb', line 1165

class CompleteLifecycleActionType < Struct.new(
  :lifecycle_hook_name,
  :auto_scaling_group_name,
  :lifecycle_action_token,
  :lifecycle_action_result,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_action_resultString

The action for the group to take. You can specify either CONTINUE or ABANDON.



1165
1166
1167
1168
1169
1170
1171
1172
1173
# File 'lib/aws-sdk-autoscaling/types.rb', line 1165

class CompleteLifecycleActionType < Struct.new(
  :lifecycle_hook_name,
  :auto_scaling_group_name,
  :lifecycle_action_token,
  :lifecycle_action_result,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_action_tokenString

A universally unique identifier (UUID) that identifies a specific lifecycle action associated with an instance. Amazon EC2 Auto Scaling sends this token to the notification target you specified when you created the lifecycle hook.



1165
1166
1167
1168
1169
1170
1171
1172
1173
# File 'lib/aws-sdk-autoscaling/types.rb', line 1165

class CompleteLifecycleActionType < Struct.new(
  :lifecycle_hook_name,
  :auto_scaling_group_name,
  :lifecycle_action_token,
  :lifecycle_action_result,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_hook_nameString

The name of the lifecycle hook.



1165
1166
1167
1168
1169
1170
1171
1172
1173
# File 'lib/aws-sdk-autoscaling/types.rb', line 1165

class CompleteLifecycleActionType < Struct.new(
  :lifecycle_hook_name,
  :auto_scaling_group_name,
  :lifecycle_action_token,
  :lifecycle_action_result,
  :instance_id)
  SENSITIVE = []
  include Aws::Structure
end