Class: Aws::AutoScaling::Types::CpuPerformanceFactorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

The CPU performance to consider, using an instance family as the baseline reference.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#referencesArray<Types::PerformanceFactorReferenceRequest>

Specify an instance family to use as the baseline reference for CPU performance. All instance types that match your specified attributes will be compared against the CPU performance of the referenced instance family, regardless of CPU manufacturer or architecture differences.

Currently only one instance family can be specified in the list.

Returns:



1192
1193
1194
1195
1196
# File 'lib/aws-sdk-autoscaling/types.rb', line 1192

class CpuPerformanceFactorRequest < Struct.new(
  :references)
  SENSITIVE = []
  include Aws::Structure
end