Class: Aws::AutoScaling::Types::DescribeInstanceRefreshesAnswer
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeInstanceRefreshesAnswer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_refreshes ⇒ Array<Types::InstanceRefresh>
The instance refreshes for the specified group, sorted by creation timestamp in descending order.
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
Instance Attribute Details
#instance_refreshes ⇒ Array<Types::InstanceRefresh>
The instance refreshes for the specified group, sorted by creation timestamp in descending order.
2278 2279 2280 2281 2282 2283 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2278 class DescribeInstanceRefreshesAnswer < Struct.new( :instance_refreshes, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
2278 2279 2280 2281 2282 2283 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2278 class DescribeInstanceRefreshesAnswer < Struct.new( :instance_refreshes, :next_token) SENSITIVE = [] include Aws::Structure end |