Class: Aws::AutoScaling::Types::DescribeLoadBalancersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeLoadBalancersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#load_balancers ⇒ Array<Types::LoadBalancerState>
The load balancers.
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
Instance Attribute Details
#load_balancers ⇒ Array<Types::LoadBalancerState>
The load balancers.
2435 2436 2437 2438 2439 2440 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2435 class DescribeLoadBalancersResponse < Struct.new( :load_balancers, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
2435 2436 2437 2438 2439 2440 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2435 class DescribeLoadBalancersResponse < Struct.new( :load_balancers, :next_token) SENSITIVE = [] include Aws::Structure end |