Class: Aws::AutoScaling::Types::DescribeTrafficSourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeTrafficSourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#max_records ⇒ Integer
The maximum number of items to return with this call.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#traffic_source_type ⇒ String
The traffic source type that you want to describe.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
2717 2718 2719 2720 2721 2722 2723 2724 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2717 class DescribeTrafficSourcesRequest < Struct.new( :auto_scaling_group_name, :traffic_source_type, :next_token, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of items to return with this call. The maximum
value is 50.
2717 2718 2719 2720 2721 2722 2723 2724 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2717 class DescribeTrafficSourcesRequest < Struct.new( :auto_scaling_group_name, :traffic_source_type, :next_token, :max_records) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
2717 2718 2719 2720 2721 2722 2723 2724 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2717 class DescribeTrafficSourcesRequest < Struct.new( :auto_scaling_group_name, :traffic_source_type, :next_token, :max_records) SENSITIVE = [] include Aws::Structure end |
#traffic_source_type ⇒ String
The traffic source type that you want to describe.
The following lists the valid values:
-
elbif the traffic source is a Classic Load Balancer. -
elbv2if the traffic source is a Application Load Balancer, Gateway Load Balancer, or Network Load Balancer. -
vpc-latticeif the traffic source is VPC Lattice.
2717 2718 2719 2720 2721 2722 2723 2724 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2717 class DescribeTrafficSourcesRequest < Struct.new( :auto_scaling_group_name, :traffic_source_type, :next_token, :max_records) SENSITIVE = [] include Aws::Structure end |