Class: Aws::AutoScaling::Types::DisableMetricsCollectionQuery
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DisableMetricsCollectionQuery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#metrics ⇒ Array<String>
Identifies the metrics to disable.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
3027 3028 3029 3030 3031 3032 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 3027 class DisableMetricsCollectionQuery < Struct.new( :auto_scaling_group_name, :metrics) SENSITIVE = [] include Aws::Structure end |
#metrics ⇒ Array<String>
Identifies the metrics to disable.
You can specify one or more of the following metrics:
-
GroupMinSize -
GroupMaxSize -
GroupDesiredCapacity -
GroupInServiceInstances -
GroupPendingInstances -
GroupStandbyInstances -
GroupTerminatingInstances -
GroupTotalInstances -
GroupInServiceCapacity -
GroupPendingCapacity -
GroupStandbyCapacity -
GroupTerminatingCapacity -
GroupTotalCapacity -
WarmPoolDesiredCapacity -
WarmPoolWarmedCapacity -
WarmPoolPendingCapacity -
WarmPoolTerminatingCapacity -
WarmPoolTotalCapacity -
GroupAndWarmPoolDesiredCapacity -
GroupAndWarmPoolTotalCapacity
If you omit this property, all metrics are disabled.
For more information, see Amazon CloudWatch metrics for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.
3027 3028 3029 3030 3031 3032 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 3027 class DisableMetricsCollectionQuery < Struct.new( :auto_scaling_group_name, :metrics) SENSITIVE = [] include Aws::Structure end |