Class: Aws::AutoScaling::Types::ExecutePolicyType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::ExecutePolicyType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#breach_threshold ⇒ Float
The breach threshold for the alarm.
-
#honor_cooldown ⇒ Boolean
Indicates whether Amazon EC2 Auto Scaling waits for the cooldown period to complete before executing the policy.
-
#metric_value ⇒ Float
The metric value to compare to
BreachThreshold. -
#policy_name ⇒ String
The name or ARN of the policy.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
3409 3410 3411 3412 3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 3409 class ExecutePolicyType < Struct.new( :auto_scaling_group_name, :policy_name, :honor_cooldown, :metric_value, :breach_threshold) SENSITIVE = [] include Aws::Structure end |
#breach_threshold ⇒ Float
The breach threshold for the alarm.
Required if the policy type is StepScaling and not supported
otherwise.
3409 3410 3411 3412 3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 3409 class ExecutePolicyType < Struct.new( :auto_scaling_group_name, :policy_name, :honor_cooldown, :metric_value, :breach_threshold) SENSITIVE = [] include Aws::Structure end |
#honor_cooldown ⇒ Boolean
Indicates whether Amazon EC2 Auto Scaling waits for the cooldown period to complete before executing the policy.
Valid only if the policy type is SimpleScaling. For more
information, see Scaling cooldowns for Amazon EC2 Auto Scaling
in the Amazon EC2 Auto Scaling User Guide.
3409 3410 3411 3412 3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 3409 class ExecutePolicyType < Struct.new( :auto_scaling_group_name, :policy_name, :honor_cooldown, :metric_value, :breach_threshold) SENSITIVE = [] include Aws::Structure end |
#metric_value ⇒ Float
The metric value to compare to BreachThreshold. This enables you
to execute a policy of type StepScaling and determine which step
adjustment to use. For example, if the breach threshold is 50 and
you want to use a step adjustment with a lower bound of 0 and an
upper bound of 10, you can set the metric value to 59.
If you specify a metric value that doesn't correspond to a step adjustment for the policy, the call returns an error.
Required if the policy type is StepScaling and not supported
otherwise.
3409 3410 3411 3412 3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 3409 class ExecutePolicyType < Struct.new( :auto_scaling_group_name, :policy_name, :honor_cooldown, :metric_value, :breach_threshold) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The name or ARN of the policy.
3409 3410 3411 3412 3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 3409 class ExecutePolicyType < Struct.new( :auto_scaling_group_name, :policy_name, :honor_cooldown, :metric_value, :breach_threshold) SENSITIVE = [] include Aws::Structure end |