Class: Aws::AutoScaling::Types::InstanceLifecyclePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

The instance lifecycle policy for the Auto Scaling group. This policy controls instance behavior when an instance transitions through its lifecycle states. Configure retention triggers to specify when instances should move to a ‘Retained` state instead of automatic termination.

For more information, see [ Control instance retention with instance lifecycle policies] in the *Amazon EC2 Auto Scaling User Guide*.

[1]: docs.aws.amazon.com/autoscaling/ec2/userguide/instance-lifecycle-policy.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#retention_triggersTypes::RetentionTriggers

Specifies the conditions that trigger instance retention behavior. These triggers determine when instances should move to a ‘Retained` state instead of automatic termination. This allows you to maintain control over instance management when lifecycles transition and operations fail.



3758
3759
3760
3761
3762
# File 'lib/aws-sdk-autoscaling/types.rb', line 3758

class InstanceLifecyclePolicy < Struct.new(
  :retention_triggers)
  SENSITIVE = []
  include Aws::Structure
end