Class: Aws::AutoScaling::Types::LaunchConfigurationsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::LaunchConfigurationsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#launch_configurations ⇒ Array<Types::LaunchConfiguration>
The launch configurations.
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
Instance Attribute Details
#launch_configurations ⇒ Array<Types::LaunchConfiguration>
The launch configurations.
4988 4989 4990 4991 4992 4993 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 4988 class LaunchConfigurationsType < Struct.new( :launch_configurations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
4988 4989 4990 4991 4992 4993 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 4988 class LaunchConfigurationsType < Struct.new( :launch_configurations, :next_token) SENSITIVE = [] include Aws::Structure end |