Class: Aws::AutoScaling::Types::LaunchInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::LaunchInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group to launch instances into.
-
#availability_zone_ids ⇒ Array<String>
A list of Availability Zone IDs where instances should be launched.
-
#availability_zones ⇒ Array<String>
The Availability Zones for the instance launch.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#requested_capacity ⇒ Integer
The number of instances to launch.
-
#retry_strategy ⇒ String
Specifies whether to retry asynchronously if the synchronous launch fails.
-
#subnet_ids ⇒ Array<String>
The subnet IDs for the instance launch.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group to launch instances into.
5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5049 class LaunchInstancesRequest < Struct.new( :auto_scaling_group_name, :requested_capacity, :client_token, :availability_zones, :availability_zone_ids, :subnet_ids, :retry_strategy) SENSITIVE = [] include Aws::Structure end |
#availability_zone_ids ⇒ Array<String>
A list of Availability Zone IDs where instances should be launched. Must match or be included in the group’s AZ configuration. You cannot specify both AvailabilityZones and AvailabilityZoneIds. Required for multi-AZ groups, optional for single-AZ groups.
5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5049 class LaunchInstancesRequest < Struct.new( :auto_scaling_group_name, :requested_capacity, :client_token, :availability_zones, :availability_zone_ids, :subnet_ids, :retry_strategy) SENSITIVE = [] include Aws::Structure end |
#availability_zones ⇒ Array<String>
The Availability Zones for the instance launch. Must match or be included in the Auto Scaling group’s Availability Zone configuration. Either ‘AvailabilityZones` or `SubnetIds` must be specified for groups with multiple Availability Zone configurations.
5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5049 class LaunchInstancesRequest < Struct.new( :auto_scaling_group_name, :requested_capacity, :client_token, :availability_zones, :availability_zone_ids, :subnet_ids, :retry_strategy) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5049 class LaunchInstancesRequest < Struct.new( :auto_scaling_group_name, :requested_capacity, :client_token, :availability_zones, :availability_zone_ids, :subnet_ids, :retry_strategy) SENSITIVE = [] include Aws::Structure end |
#requested_capacity ⇒ Integer
The number of instances to launch. Although this value can exceed 100 for instance weights, the actual instance count is limited to 100 instances per launch.
5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5049 class LaunchInstancesRequest < Struct.new( :auto_scaling_group_name, :requested_capacity, :client_token, :availability_zones, :availability_zone_ids, :subnet_ids, :retry_strategy) SENSITIVE = [] include Aws::Structure end |
#retry_strategy ⇒ String
Specifies whether to retry asynchronously if the synchronous launch fails. Valid values are NONE (default, no async retry) and RETRY_WITH_GROUP_CONFIGURATION (increase desired capacity and retry with group configuration).
5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5049 class LaunchInstancesRequest < Struct.new( :auto_scaling_group_name, :requested_capacity, :client_token, :availability_zones, :availability_zone_ids, :subnet_ids, :retry_strategy) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The subnet IDs for the instance launch. Either ‘AvailabilityZones` or `SubnetIds` must be specified. If both are specified, the subnets must reside in the specified Availability Zones.
5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5049 class LaunchInstancesRequest < Struct.new( :auto_scaling_group_name, :requested_capacity, :client_token, :availability_zones, :availability_zone_ids, :subnet_ids, :retry_strategy) SENSITIVE = [] include Aws::Structure end |