Class: Aws::AutoScaling::Types::LimitExceededFault
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::LimitExceededFault
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
You have already reached a limit for your Amazon EC2 Auto Scaling resources (for example, Auto Scaling groups, launch configurations, or lifecycle hooks). For more information, see DescribeAccountLimits in the Amazon EC2 Auto Scaling API Reference.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
5576 5577 5578 5579 5580 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5576 class LimitExceededFault < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |