Class: Aws::AutoScaling::Types::MixedInstancesPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Use this structure to launch multiple instance types and configure how capacity is distributed across On-Demand, Spot, and supported Capacity Reservation types within a single Auto Scaling group.

A mixed instances policy contains information that Amazon EC2 Auto Scaling can use to launch instances, prioritize capacity types, and help optimize your costs. For more information, see Auto Scaling groups with multiple instance types and purchase options in the Amazon EC2 Auto Scaling User Guide. To learn how to prioritize multiple capacity types, see Use Distribution Segments to target multiple capacity types in the Amazon EC2 Auto Scaling User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instances_distributionTypes::InstancesDistribution

The instances distribution.



6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-autoscaling/types.rb', line 6014

class MixedInstancesPolicy < Struct.new(
  :launch_template,
  :instances_distribution)
  SENSITIVE = []
  include Aws::Structure
end

#launch_templateTypes::LaunchTemplate

One or more launch templates and the instance types (overrides) that are used to launch EC2 instances to fulfill the configured capacities.



6014
6015
6016
6017
6018
6019
# File 'lib/aws-sdk-autoscaling/types.rb', line 6014

class MixedInstancesPolicy < Struct.new(
  :launch_template,
  :instances_distribution)
  SENSITIVE = []
  include Aws::Structure
end