Class: Aws::AutoScaling::Types::PutNotificationConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::PutNotificationConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#notification_types ⇒ Array<String>
The type of event that causes the notification to be sent.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS topic.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
6779 6780 6781 6782 6783 6784 6785 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6779 class PutNotificationConfigurationType < Struct.new( :auto_scaling_group_name, :topic_arn, :notification_types) SENSITIVE = [] include Aws::Structure end |
#notification_types ⇒ Array<String>
The type of event that causes the notification to be sent. To query the notification types supported by Amazon EC2 Auto Scaling, call the DescribeAutoScalingNotificationTypes API.
6779 6780 6781 6782 6783 6784 6785 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6779 class PutNotificationConfigurationType < Struct.new( :auto_scaling_group_name, :topic_arn, :notification_types) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS topic.
6779 6780 6781 6782 6783 6784 6785 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6779 class PutNotificationConfigurationType < Struct.new( :auto_scaling_group_name, :topic_arn, :notification_types) SENSITIVE = [] include Aws::Structure end |