Class: Aws::AutoScaling::Types::PutScheduledUpdateGroupActionType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::PutScheduledUpdateGroupActionType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#desired_capacity ⇒ Integer
The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.
-
#end_time ⇒ Time
The date and time for the recurring schedule to end, in UTC.
-
#max_size ⇒ Integer
The maximum size of the Auto Scaling group.
-
#min_size ⇒ Integer
The minimum size of the Auto Scaling group.
-
#recurrence ⇒ String
The recurring schedule for this action.
-
#scheduled_action_name ⇒ String
The name of this scaling action.
-
#start_time ⇒ Time
The date and time for this action to start, in YYYY-MM-DDThh:mm:ssZ format in UTC/GMT only and in quotes (for example, ‘“2021-06-01T00:00:00Z”`).
-
#time ⇒ Time
This property is no longer used.
-
#time_zone ⇒ String
Specifies the time zone for a cron expression.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#desired_capacity ⇒ Integer
The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain. It can scale beyond this capacity if you add more scaling conditions.
<note markdown=“1”> You must specify at least one of the following properties: ‘MaxSize`, `MinSize`, or `DesiredCapacity`.
</note>
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time for the recurring schedule to end, in UTC. For example, ‘“2021-06-01T00:00:00Z”`.
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#max_size ⇒ Integer
The maximum size of the Auto Scaling group.
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#min_size ⇒ Integer
The minimum size of the Auto Scaling group.
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#recurrence ⇒ String
The recurring schedule for this action. This format consists of five fields separated by white spaces: [Minute] [Hour] [Day_of_Month] [Month_of_Year] [Day_of_Week]. The value must be in quotes (for example, ‘“30 0 1 1,6,12 *”`). For more information about this format, see [Crontab].
When ‘StartTime` and `EndTime` are specified with `Recurrence`, they form the boundaries of when the recurring action starts and stops.
Cron expressions use Universal Coordinated Time (UTC) by default.
[1]: crontab.org
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#scheduled_action_name ⇒ String
The name of this scaling action.
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time for this action to start, in YYYY-MM-DDThh:mm:ssZ format in UTC/GMT only and in quotes (for example, ‘“2021-06-01T00:00:00Z”`).
If you specify ‘Recurrence` and `StartTime`, Amazon EC2 Auto Scaling performs the action at this time, and then performs the action based on the specified recurrence.
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Time
This property is no longer used.
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
Specifies the time zone for a cron expression. If a time zone is not provided, UTC is used by default.
Valid values are the canonical names of the IANA time zones, derived from the IANA Time Zone Database (such as ‘Etc/GMT+9` or `Pacific/Tahiti`). For more information, see [en.wikipedia.org/wiki/List_of_tz_database_time_zones][1].
7012 7013 7014 7015 7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7012 class PutScheduledUpdateGroupActionType < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |