Class: Aws::AutoScaling::Types::ScheduledUpdateGroupAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Describes a scheduled scaling action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_nameString

The name of the Auto Scaling group.

Returns:

  • (String)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#desired_capacityInteger

The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.

Returns:

  • (Integer)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The date and time in UTC for the recurring schedule to end. For example, "2019-06-01T00:00:00Z".

Returns:

  • (Time)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#max_sizeInteger

The maximum size of the Auto Scaling group.

Returns:

  • (Integer)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#min_sizeInteger

The minimum size of the Auto Scaling group.

Returns:

  • (Integer)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#recurrenceString

The recurring schedule for the action, in Unix cron syntax format.

When StartTime and EndTime are specified with Recurrence, they form the boundaries of when the recurring action starts and stops.

Returns:

  • (String)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_action_arnString

The Amazon Resource Name (ARN) of the scheduled action.

Returns:

  • (String)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_action_nameString

The name of the scheduled action.

Returns:

  • (String)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The date and time in UTC for this action to start. For example, "2019-06-01T00:00:00Z".

Returns:

  • (Time)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#timeTime

This property is no longer used.

Returns:

  • (Time)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#time_zoneString

The time zone for the cron expression.

Returns:

  • (String)


7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
# File 'lib/aws-sdk-autoscaling/types.rb', line 7739

class ScheduledUpdateGroupAction < Struct.new(
  :auto_scaling_group_name,
  :scheduled_action_name,
  :scheduled_action_arn,
  :time,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end