Class: Aws::AutoScaling::Types::ScheduledUpdateGroupActionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Describes information used for one or more scheduled scaling action updates in a BatchPutScheduledUpdateGroupAction operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#desired_capacityInteger

The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.

Returns:

  • (Integer)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
# File 'lib/aws-sdk-autoscaling/types.rb', line 7831

class ScheduledUpdateGroupActionRequest < Struct.new(
  :scheduled_action_name,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The date and time for the recurring schedule to end, in UTC.

Returns:

  • (Time)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
# File 'lib/aws-sdk-autoscaling/types.rb', line 7831

class ScheduledUpdateGroupActionRequest < Struct.new(
  :scheduled_action_name,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#max_sizeInteger

The maximum size of the Auto Scaling group.

Returns:

  • (Integer)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
# File 'lib/aws-sdk-autoscaling/types.rb', line 7831

class ScheduledUpdateGroupActionRequest < Struct.new(
  :scheduled_action_name,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#min_sizeInteger

The minimum size of the Auto Scaling group.

Returns:

  • (Integer)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
# File 'lib/aws-sdk-autoscaling/types.rb', line 7831

class ScheduledUpdateGroupActionRequest < Struct.new(
  :scheduled_action_name,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#recurrenceString

The recurring schedule for the action, in Unix cron syntax format. This format consists of five fields separated by white spaces: [Minute] [Hour] [Day_of_Month] [Month_of_Year] [Day_of_Week]. The value must be in quotes (for example, "30 0 1 1,6,12 *"). For more information about this format, see Crontab.

When StartTime and EndTime are specified with Recurrence, they form the boundaries of when the recurring action starts and stops.

Cron expressions use Universal Coordinated Time (UTC) by default.

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
# File 'lib/aws-sdk-autoscaling/types.rb', line 7831

class ScheduledUpdateGroupActionRequest < Struct.new(
  :scheduled_action_name,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_action_nameString

The name of the scaling action.

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
# File 'lib/aws-sdk-autoscaling/types.rb', line 7831

class ScheduledUpdateGroupActionRequest < Struct.new(
  :scheduled_action_name,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The date and time for the action to start, in YYYY-MM-DDThh:mm:ssZ format in UTC/GMT only and in quotes (for example, "2019-06-01T00:00:00Z").

If you specify Recurrence and StartTime, Amazon EC2 Auto Scaling performs the action at this time, and then performs the action based on the specified recurrence.

If you try to schedule the action in the past, Amazon EC2 Auto Scaling returns an error message.

Returns:

  • (Time)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
# File 'lib/aws-sdk-autoscaling/types.rb', line 7831

class ScheduledUpdateGroupActionRequest < Struct.new(
  :scheduled_action_name,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end

#time_zoneString

Specifies the time zone for a cron expression. If a time zone is not provided, UTC is used by default.

Valid values are the canonical names of the IANA time zones, derived from the IANA Time Zone Database (such as Etc/GMT+9 or Pacific/Tahiti). For more information, see https://en.wikipedia.org/wiki/List_of_tz_database_time_zones.

Returns:

  • (String)


7831
7832
7833
7834
7835
7836
7837
7838
7839
7840
7841
7842
# File 'lib/aws-sdk-autoscaling/types.rb', line 7831

class ScheduledUpdateGroupActionRequest < Struct.new(
  :scheduled_action_name,
  :start_time,
  :end_time,
  :recurrence,
  :min_size,
  :max_size,
  :desired_capacity,
  :time_zone)
  SENSITIVE = []
  include Aws::Structure
end