Class: Aws::AutoScaling::Types::StartInstanceRefreshType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_nameString

The name of the Auto Scaling group.

Returns:

  • (String)


7941
7942
7943
7944
7945
7946
7947
7948
# File 'lib/aws-sdk-autoscaling/types.rb', line 7941

class StartInstanceRefreshType < Struct.new(
  :auto_scaling_group_name,
  :strategy,
  :desired_configuration,
  :preferences)
  SENSITIVE = []
  include Aws::Structure
end

#desired_configurationTypes::DesiredConfiguration

The desired configuration. For example, the desired configuration can specify a new launch template or a new version of the current launch template.

Once the instance refresh succeeds, Amazon EC2 Auto Scaling updates the settings of the Auto Scaling group to reflect the new desired configuration.

<note markdown=“1”> When you specify a new launch template or a new version of the current launch template for your desired configuration, consider enabling the ‘SkipMatching` property in preferences. If it’s enabled, Amazon EC2 Auto Scaling skips replacing instances that already use the specified launch template and instance types. This can help you reduce the number of replacements that are required to apply updates.

</note>


7941
7942
7943
7944
7945
7946
7947
7948
# File 'lib/aws-sdk-autoscaling/types.rb', line 7941

class StartInstanceRefreshType < Struct.new(
  :auto_scaling_group_name,
  :strategy,
  :desired_configuration,
  :preferences)
  SENSITIVE = []
  include Aws::Structure
end

#preferencesTypes::RefreshPreferences

Sets your preferences for the instance refresh so that it performs as expected when you start it. Includes the instance warmup time, the minimum and maximum healthy percentages, and the behaviors that you want Amazon EC2 Auto Scaling to use if instances that are in ‘Standby` state or protected from scale in are found. You can also choose to enable additional features, such as the following:

  • Auto rollback

  • Checkpoints

  • CloudWatch alarms

  • Skip matching

  • Bake time



7941
7942
7943
7944
7945
7946
7947
7948
# File 'lib/aws-sdk-autoscaling/types.rb', line 7941

class StartInstanceRefreshType < Struct.new(
  :auto_scaling_group_name,
  :strategy,
  :desired_configuration,
  :preferences)
  SENSITIVE = []
  include Aws::Structure
end

#strategyString

The strategy to use for the instance refresh. The default value is ‘Rolling`.

Returns:

  • (String)


7941
7942
7943
7944
7945
7946
7947
7948
# File 'lib/aws-sdk-autoscaling/types.rb', line 7941

class StartInstanceRefreshType < Struct.new(
  :auto_scaling_group_name,
  :strategy,
  :desired_configuration,
  :preferences)
  SENSITIVE = []
  include Aws::Structure
end