Class: Aws::AutoScaling::Types::TargetTrackingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::TargetTrackingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Represents a target tracking scaling policy configuration to use with Amazon EC2 Auto Scaling.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customized_metric_specification ⇒ Types::CustomizedMetricSpecification
A customized metric.
-
#disable_scale_in ⇒ Boolean
Indicates whether scaling in by the target tracking scaling policy is disabled.
-
#predefined_metric_specification ⇒ Types::PredefinedMetricSpecification
A predefined metric.
-
#target_value ⇒ Float
The target value for the metric.
Instance Attribute Details
#customized_metric_specification ⇒ Types::CustomizedMetricSpecification
A customized metric. You must specify either a predefined metric or a customized metric.
8178 8179 8180 8181 8182 8183 8184 8185 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8178 class TargetTrackingConfiguration < Struct.new( :predefined_metric_specification, :customized_metric_specification, :target_value, :disable_scale_in) SENSITIVE = [] include Aws::Structure end |
#disable_scale_in ⇒ Boolean
Indicates whether scaling in by the target tracking scaling policy is disabled. If scaling in is disabled, the target tracking scaling policy doesn’t remove instances from the Auto Scaling group. Otherwise, the target tracking scaling policy can remove instances from the Auto Scaling group. The default is ‘false`.
8178 8179 8180 8181 8182 8183 8184 8185 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8178 class TargetTrackingConfiguration < Struct.new( :predefined_metric_specification, :customized_metric_specification, :target_value, :disable_scale_in) SENSITIVE = [] include Aws::Structure end |
#predefined_metric_specification ⇒ Types::PredefinedMetricSpecification
A predefined metric. You must specify either a predefined metric or a customized metric.
8178 8179 8180 8181 8182 8183 8184 8185 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8178 class TargetTrackingConfiguration < Struct.new( :predefined_metric_specification, :customized_metric_specification, :target_value, :disable_scale_in) SENSITIVE = [] include Aws::Structure end |
#target_value ⇒ Float
The target value for the metric.
<note markdown=“1”> Some metrics are based on a count instead of a percentage, such as the request count for an Application Load Balancer or the number of messages in an SQS queue. If the scaling policy specifies one of these metrics, specify the target utilization as the optimal average request or message count per instance during any one-minute interval.
</note>
8178 8179 8180 8181 8182 8183 8184 8185 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8178 class TargetTrackingConfiguration < Struct.new( :predefined_metric_specification, :customized_metric_specification, :target_value, :disable_scale_in) SENSITIVE = [] include Aws::Structure end |