Class: Aws::AutoScaling::Types::TerminateInstanceInAutoScalingGroupType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::TerminateInstanceInAutoScalingGroupType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#instance_id ⇒ String
The ID of the instance.
-
#instance_ids ⇒ Array<String>
The IDs of the instances.
-
#should_decrement_desired_capacity ⇒ Boolean
Indicates whether terminating the instance also decrements the size of the Auto Scaling group.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group. Required when using
InstanceIds.
8416 8417 8418 8419 8420 8421 8422 8423 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8416 class TerminateInstanceInAutoScalingGroupType < Struct.new( :instance_id, :instance_ids, :auto_scaling_group_name, :should_decrement_desired_capacity) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
8416 8417 8418 8419 8420 8421 8422 8423 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8416 class TerminateInstanceInAutoScalingGroupType < Struct.new( :instance_id, :instance_ids, :auto_scaling_group_name, :should_decrement_desired_capacity) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The IDs of the instances. You can specify up to 100 instances.
This parameter requires that you also specify
AutoScalingGroupName.
8416 8417 8418 8419 8420 8421 8422 8423 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8416 class TerminateInstanceInAutoScalingGroupType < Struct.new( :instance_id, :instance_ids, :auto_scaling_group_name, :should_decrement_desired_capacity) SENSITIVE = [] include Aws::Structure end |
#should_decrement_desired_capacity ⇒ Boolean
Indicates whether terminating the instance also decrements the size of the Auto Scaling group.
8416 8417 8418 8419 8420 8421 8422 8423 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8416 class TerminateInstanceInAutoScalingGroupType < Struct.new( :instance_id, :instance_ids, :auto_scaling_group_name, :should_decrement_desired_capacity) SENSITIVE = [] include Aws::Structure end |