Class: Aws::AutoScaling::Waiters::GroupExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-autoscaling/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ GroupExists

Returns a new instance of GroupExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 10
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


86
87
# File 'lib/aws-sdk-autoscaling/waiters.rb', line 86

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



118
119
120
# File 'lib/aws-sdk-autoscaling/waiters.rb', line 118

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::AutoScalingGroupsType

Returns a response object which responds to the following methods:

Options Hash (params):

  • :auto_scaling_group_names (Array<String>)

    The names of the Auto Scaling groups. By default, you can only specify up to 50 names. You can optionally increase this limit using the MaxRecords property.

    If you omit this property, all Auto Scaling groups are described.

  • :include_instances (Boolean)

    Specifies whether to include information about Amazon EC2 instances in the response. When set to true (default), the response includes instance details.

  • :next_token (String)

    The token for the next set of items to return. (You received this token from a previous call.)

  • :max_records (Integer)

    The maximum number of items to return with this call. The default value is 50 and the maximum value is 100.

  • :filters (Array<Types::Filter>)

    One or more filters to limit the results based on specific tags.

Returns:



113
# File 'lib/aws-sdk-autoscaling/waiters.rb', line 113

def wait: (