Class: Aws::AutoScaling::Activity
- Inherits:
-
Object
- Object
- Aws::AutoScaling::Activity
- Extended by:
- Deprecations
- Defined in:
- sig/activity.rbs,
lib/aws-sdk-autoscaling/activity.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#auto_scaling_group_arn ⇒ String
The Amazon Resource Name (ARN) of the Auto Scaling group.
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#auto_scaling_group_state ⇒ String
The state of the Auto Scaling group, which is either
InServiceorDeleted. -
#cause ⇒ String
The reason the activity began.
-
#description ⇒ String
A friendly, more verbose description of the activity.
-
#details ⇒ String
The details about the activity.
-
#end_time ⇒ Time
The end time of the activity.
- #id ⇒ String (also: #activity_id)
-
#progress ⇒ Integer
A value between 0 and 100 that indicates the progress of the activity.
-
#start_time ⇒ Time
The start time of the activity.
-
#status_code ⇒ String
The current status of the activity.
-
#status_message ⇒ String
A friendly, more verbose description of the activity status.
Associations collapse
- #group ⇒ AutoScalingGroup?
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::Activity
Returns the data for this Activity.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ Activity
constructor
A new instance of Activity.
- #load ⇒ self (also: #reload)
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::AutoScaling::Client] #wait_until instead
Constructor Details
#initialize(id, options = {}) ⇒ Activity #initialize(options = {}) ⇒ Activity
Returns a new instance of Activity.
13 14 15 |
# File 'sig/activity.rbs', line 13
def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#auto_scaling_group_arn ⇒ String
The Amazon Resource Name (ARN) of the Auto Scaling group.
52 |
# File 'sig/activity.rbs', line 52
def auto_scaling_group_arn: () -> ::String
|
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
22 |
# File 'sig/activity.rbs', line 22
def auto_scaling_group_name: () -> ::String
|
#auto_scaling_group_state ⇒ String
The state of the Auto Scaling group, which is either InService or
Deleted.
49 |
# File 'sig/activity.rbs', line 49
def auto_scaling_group_state: () -> ::String
|
#cause ⇒ String
The reason the activity began.
28 |
# File 'sig/activity.rbs', line 28
def cause: () -> ::String
|
#client ⇒ Client
108 |
# File 'lib/aws-sdk-autoscaling/activity.rb', line 108
def client: () -> Client
|
#data ⇒ Types::Activity
Returns the data for this Aws::AutoScaling::Activity. Calls
Client#describe_scaling_activities if #data_loaded? is false.
61 |
# File 'sig/activity.rbs', line 61
def data: () -> Types::Activity
|
#data_loaded? ⇒ Boolean
64 |
# File 'sig/activity.rbs', line 64
def data_loaded?: () -> bool
|
#description ⇒ String
A friendly, more verbose description of the activity.
25 |
# File 'sig/activity.rbs', line 25
def description: () -> ::String
|
#details ⇒ String
The details about the activity.
46 |
# File 'sig/activity.rbs', line 46
def details: () -> ::String
|
#end_time ⇒ Time
The end time of the activity.
34 |
# File 'sig/activity.rbs', line 34
def end_time: () -> ::Time
|
#id ⇒ String Also known as: activity_id
18 |
# File 'sig/activity.rbs', line 18
def id: () -> String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
257 258 259 |
# File 'lib/aws-sdk-autoscaling/activity.rb', line 257 def identifiers { id: @id } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::AutoScaling::Activity.
Returns self making it possible to chain methods.
activity.reload.data
57 |
# File 'sig/activity.rbs', line 57
def load: () -> self
|
#progress ⇒ Integer
A value between 0 and 100 that indicates the progress of the activity.
43 |
# File 'sig/activity.rbs', line 43
def progress: () -> ::Integer
|
#start_time ⇒ Time
The start time of the activity.
31 |
# File 'sig/activity.rbs', line 31
def start_time: () -> ::Time
|
#status_code ⇒ String
The current status of the activity.
37 |
# File 'sig/activity.rbs', line 37
def status_code: () -> ("PendingSpotBidPlacement" | "WaitingForSpotInstanceRequestId" | "WaitingForSpotInstanceId" | "WaitingForInstanceId" | "PreInService" | "InProgress" | "WaitingForELBConnectionDraining" | "MidLifecycleAction" | "WaitingForInstanceWarmup" | "Successful" | "Failed" | "Cancelled" | "WaitingForConnectionDraining" | "WaitingForInPlaceUpdateToStart" | "WaitingForInPlaceUpdateToFinalize" | "InPlaceUpdateInProgress")
|
#status_message ⇒ String
A friendly, more verbose description of the activity status.
40 |
# File 'sig/activity.rbs', line 40
def status_message: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::AutoScaling::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/aws-sdk-autoscaling/activity.rb', line 222 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |