Class: Aws::AutoScaling::Instance::Collection

Inherits:
Resources::Collection
  • Object
show all
Defined in:
lib/aws-sdk-autoscaling/instance.rb

Batch Actions collapse

Instance Method Details

#batch_attach(options = {}) ⇒ void

This method returns an undefined value.

Parameters:

  • options ({}) (defaults to: {})


503
504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/aws-sdk-autoscaling/instance.rb', line 503

def batch_attach(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:auto_scaling_group_name] = batch[0].group_name
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.attach_instances(params)
    end
  end
  nil
end

#batch_detach(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_detach({
  should_decrement_desired_capacity: false, # required
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :should_decrement_desired_capacity (required, Boolean)

    Indicates whether the Auto Scaling group decrements the desired capacity value by the number of instances detached.



528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/aws-sdk-autoscaling/instance.rb', line 528

def batch_detach(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:auto_scaling_group_name] = batch[0].group_name
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.detach_instances(params)
    end
  end
  nil
end

#batch_enter_standby(options = {}) ⇒ void

This method returns an undefined value.

Examples:

Request syntax with placeholder values


instance.batch_enter_standby({
  should_decrement_desired_capacity: false, # required
})

Parameters:

  • options ({}) (defaults to: {})

Options Hash (options):

  • :should_decrement_desired_capacity (required, Boolean)

    Indicates whether to decrement the desired capacity of the Auto Scaling group by the number of instances moved to ‘Standby` mode.



553
554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/aws-sdk-autoscaling/instance.rb', line 553

def batch_enter_standby(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:auto_scaling_group_name] = batch[0].group_name
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.enter_standby(params)
    end
  end
  nil
end

#batch_exit_standby(options = {}) ⇒ void

This method returns an undefined value.

Parameters:

  • options ({}) (defaults to: {})


570
571
572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/aws-sdk-autoscaling/instance.rb', line 570

def batch_exit_standby(options = {})
  batch_enum.each do |batch|
    params = Aws::Util.copy_hash(options)
    params[:auto_scaling_group_name] = batch[0].group_name
    params[:instance_ids] ||= []
    batch.each do |item|
      params[:instance_ids] << item.id
    end
    Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
      batch[0].client.exit_standby(params)
    end
  end
  nil
end