Class: Aws::AutoScaling::ScheduledAction
- Inherits:
-
Object
- Object
- Aws::AutoScaling::ScheduledAction
- Extended by:
- Deprecations
- Defined in:
- sig/scheduled_action.rbs,
lib/aws-sdk-autoscaling/scheduled_action.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#desired_capacity ⇒ Integer
The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.
-
#end_time ⇒ Time
The date and time in UTC for the recurring schedule to end.
-
#max_size ⇒ Integer
The maximum size of the Auto Scaling group.
-
#min_size ⇒ Integer
The minimum size of the Auto Scaling group.
- #name ⇒ String (also: #scheduled_action_name)
-
#recurrence ⇒ String
The recurring schedule for the action, in Unix cron syntax format.
-
#scheduled_action_arn ⇒ String
The Amazon Resource Name (ARN) of the scheduled action.
-
#start_time ⇒ Time
The date and time in UTC for this action to start.
-
#time ⇒ Time
This property is no longer used.
-
#time_zone ⇒ String
The time zone for the cron expression.
Actions collapse
Associations collapse
- #group ⇒ AutoScalingGroup?
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::ScheduledUpdateGroupAction
Returns the data for this ScheduledAction.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ ScheduledAction
constructor
A new instance of ScheduledAction.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current ScheduledAction.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::AutoScaling::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ ScheduledAction #initialize(options = {}) ⇒ ScheduledAction
Returns a new instance of ScheduledAction.
13 14 15 |
# File 'sig/scheduled_action.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
22 |
# File 'sig/scheduled_action.rbs', line 22
def auto_scaling_group_name: () -> ::String
|
#client ⇒ Client
108 |
# File 'lib/aws-sdk-autoscaling/scheduled_action.rb', line 108
def client: () -> Client
|
#data ⇒ Types::ScheduledUpdateGroupAction
Returns the data for this Aws::AutoScaling::ScheduledAction. Calls
Client#describe_scheduled_actions if #data_loaded? is false.
58 |
# File 'sig/scheduled_action.rbs', line 58
def data: () -> Types::ScheduledUpdateGroupAction
|
#data_loaded? ⇒ Boolean
61 |
# File 'sig/scheduled_action.rbs', line 61
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
65 |
# File 'sig/scheduled_action.rbs', line 65
def delete: (
|
#desired_capacity ⇒ Integer
The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.
46 |
# File 'sig/scheduled_action.rbs', line 46
def desired_capacity: () -> ::Integer
|
#end_time ⇒ Time
The date and time in UTC for the recurring schedule to end. For
example, "2019-06-01T00:00:00Z".
34 |
# File 'sig/scheduled_action.rbs', line 34
def end_time: () -> ::Time
|
#group ⇒ AutoScalingGroup?
71 |
# File 'sig/scheduled_action.rbs', line 71
def group: () -> AutoScalingGroup?
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
276 277 278 |
# File 'lib/aws-sdk-autoscaling/scheduled_action.rb', line 276 def identifiers { name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::AutoScaling::ScheduledAction.
Returns self making it possible to chain methods.
scheduled_action.reload.data
54 |
# File 'sig/scheduled_action.rbs', line 54
def load: () -> self
|
#max_size ⇒ Integer
The maximum size of the Auto Scaling group.
43 |
# File 'sig/scheduled_action.rbs', line 43
def max_size: () -> ::Integer
|
#min_size ⇒ Integer
The minimum size of the Auto Scaling group.
40 |
# File 'sig/scheduled_action.rbs', line 40
def min_size: () -> ::Integer
|
#name ⇒ String Also known as: scheduled_action_name
18 |
# File 'sig/scheduled_action.rbs', line 18
def name: () -> String
|
#recurrence ⇒ String
The recurring schedule for the action, in Unix cron syntax format.
When StartTime and EndTime are specified with Recurrence, they
form the boundaries of when the recurring action starts and stops.
37 |
# File 'sig/scheduled_action.rbs', line 37
def recurrence: () -> ::String
|
#scheduled_action_arn ⇒ String
The Amazon Resource Name (ARN) of the scheduled action.
25 |
# File 'sig/scheduled_action.rbs', line 25
def scheduled_action_arn: () -> ::String
|
#start_time ⇒ Time
The date and time in UTC for this action to start. For example,
"2019-06-01T00:00:00Z".
31 |
# File 'sig/scheduled_action.rbs', line 31
def start_time: () -> ::Time
|
#time ⇒ Time
This property is no longer used.
28 |
# File 'sig/scheduled_action.rbs', line 28
def time: () -> ::Time
|
#time_zone ⇒ String
The time zone for the cron expression.
49 |
# File 'sig/scheduled_action.rbs', line 49
def time_zone: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::AutoScaling::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/aws-sdk-autoscaling/scheduled_action.rb', line 222 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |