Class: Aws::AutoScaling::Tag
- Inherits:
-
Object
- Object
- Aws::AutoScaling::Tag
- Extended by:
- Deprecations
- Defined in:
- sig/tag.rbs,
lib/aws-sdk-autoscaling/tag.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #key ⇒ String
-
#propagate_at_launch ⇒ Boolean
Determines whether the tag is added to new instances as they are launched in the group.
- #resource_id ⇒ String
- #resource_type ⇒ String
-
#value ⇒ String
The tag value.
Actions collapse
- #create(options = {}) ⇒ EmptyStructure
- #delete(options = {}) ⇒ EmptyStructure
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::TagDescription
Returns the data for this Tag.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ Tag
constructor
A new instance of Tag.
- #load ⇒ self (also: #reload)
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::AutoScaling::Client] #wait_until instead
Constructor Details
#initialize(key, resource_id, resource_type, options = {}) ⇒ Tag #initialize(options = {}) ⇒ Tag
Returns a new instance of Tag.
13 14 15 |
# File 'sig/tag.rbs', line 13
def initialize: (String key, String resource_id, String resource_type, Hash[Symbol, untyped] options) -> void
| (key: String, resource_id: String, resource_type: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#create(options = {}) ⇒ EmptyStructure
46 |
# File 'sig/tag.rbs', line 46
def create: (
|
#data ⇒ Types::TagDescription
Returns the data for this Aws::AutoScaling::Tag. Calls
Client#describe_tags if #data_loaded? is false.
39 |
# File 'sig/tag.rbs', line 39
def data: () -> Types::TagDescription
|
#data_loaded? ⇒ Boolean
42 |
# File 'sig/tag.rbs', line 42
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
60 |
# File 'sig/tag.rbs', line 60
def delete: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
273 274 275 276 277 278 279 |
# File 'lib/aws-sdk-autoscaling/tag.rb', line 273 def identifiers { key: @key, resource_id: @resource_id, resource_type: @resource_type } end |
#key ⇒ String
18 |
# File 'sig/tag.rbs', line 18
def key: () -> String
|
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::AutoScaling::Tag.
Returns self making it possible to chain methods.
tag.reload.data
35 |
# File 'sig/tag.rbs', line 35
def load: () -> self
|
#propagate_at_launch ⇒ Boolean
Determines whether the tag is added to new instances as they are launched in the group.
30 |
# File 'sig/tag.rbs', line 30
def propagate_at_launch: () -> bool
|
#resource_id ⇒ String
21 |
# File 'sig/tag.rbs', line 21
def resource_id: () -> String
|
#resource_type ⇒ String
24 |
# File 'sig/tag.rbs', line 24
def resource_type: () -> String
|
#value ⇒ String
The tag value.
27 |
# File 'sig/tag.rbs', line 27
def value: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::AutoScaling::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-autoscaling/tag.rb', line 192 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |