Class: Aws::AutoScaling::Types::CompleteLifecycleActionType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::CompleteLifecycleActionType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#instance_id ⇒ String
The ID of the instance.
-
#lifecycle_action_result ⇒ String
The action for the group to take.
-
#lifecycle_action_token ⇒ String
A universally unique identifier (UUID) that identifies a specific lifecycle action associated with an instance.
-
#lifecycle_hook_name ⇒ String
The name of the lifecycle hook.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 1159 class CompleteLifecycleActionType < Struct.new( :lifecycle_hook_name, :auto_scaling_group_name, :lifecycle_action_token, :lifecycle_action_result, :instance_id) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the instance.
1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 1159 class CompleteLifecycleActionType < Struct.new( :lifecycle_hook_name, :auto_scaling_group_name, :lifecycle_action_token, :lifecycle_action_result, :instance_id) SENSITIVE = [] include Aws::Structure end |
#lifecycle_action_result ⇒ String
The action for the group to take. You can specify either CONTINUE
or ABANDON.
1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 1159 class CompleteLifecycleActionType < Struct.new( :lifecycle_hook_name, :auto_scaling_group_name, :lifecycle_action_token, :lifecycle_action_result, :instance_id) SENSITIVE = [] include Aws::Structure end |
#lifecycle_action_token ⇒ String
A universally unique identifier (UUID) that identifies a specific lifecycle action associated with an instance. Amazon EC2 Auto Scaling sends this token to the notification target you specified when you created the lifecycle hook.
1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 1159 class CompleteLifecycleActionType < Struct.new( :lifecycle_hook_name, :auto_scaling_group_name, :lifecycle_action_token, :lifecycle_action_result, :instance_id) SENSITIVE = [] include Aws::Structure end |
#lifecycle_hook_name ⇒ String
The name of the lifecycle hook.
1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 1159 class CompleteLifecycleActionType < Struct.new( :lifecycle_hook_name, :auto_scaling_group_name, :lifecycle_action_token, :lifecycle_action_result, :instance_id) SENSITIVE = [] include Aws::Structure end |