Class: Aws::AutoScaling::Types::DeleteAutoScalingGroupType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_nameString

The name of the Auto Scaling group.

Returns:

  • (String)


2063
2064
2065
2066
2067
2068
# File 'lib/aws-sdk-autoscaling/types.rb', line 2063

class DeleteAutoScalingGroupType < Struct.new(
  :auto_scaling_group_name,
  :force_delete)
  SENSITIVE = []
  include Aws::Structure
end

#force_deleteBoolean

Specifies that the group is to be deleted along with all instances associated with the group, without waiting for all instances to be terminated. This action also deletes any outstanding lifecycle actions associated with the group.

Returns:

  • (Boolean)


2063
2064
2065
2066
2067
2068
# File 'lib/aws-sdk-autoscaling/types.rb', line 2063

class DeleteAutoScalingGroupType < Struct.new(
  :auto_scaling_group_name,
  :force_delete)
  SENSITIVE = []
  include Aws::Structure
end