Class: Aws::AutoScaling::Types::DeleteAutoScalingGroupType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DeleteAutoScalingGroupType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#force_delete ⇒ Boolean
Specifies that the group is to be deleted along with all instances associated with the group, without waiting for all instances to be terminated.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
2037 2038 2039 2040 2041 2042 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2037 class DeleteAutoScalingGroupType < Struct.new( :auto_scaling_group_name, :force_delete) SENSITIVE = [] include Aws::Structure end |
#force_delete ⇒ Boolean
Specifies that the group is to be deleted along with all instances associated with the group, without waiting for all instances to be terminated. This action also deletes any outstanding lifecycle actions associated with the group.
2037 2038 2039 2040 2041 2042 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2037 class DeleteAutoScalingGroupType < Struct.new( :auto_scaling_group_name, :force_delete) SENSITIVE = [] include Aws::Structure end |