Class: Aws::AutoScaling::Types::DeleteWarmPoolType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DeleteWarmPoolType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#force_delete ⇒ Boolean
Specifies that the warm pool is to be deleted along with all of its associated instances, without waiting for all instances to be terminated.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
2149 2150 2151 2152 2153 2154 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2149 class DeleteWarmPoolType < Struct.new( :auto_scaling_group_name, :force_delete) SENSITIVE = [] include Aws::Structure end |
#force_delete ⇒ Boolean
Specifies that the warm pool is to be deleted along with all of its associated instances, without waiting for all instances to be terminated. This parameter also deletes any outstanding lifecycle actions associated with the warm pool instances.
2149 2150 2151 2152 2153 2154 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2149 class DeleteWarmPoolType < Struct.new( :auto_scaling_group_name, :force_delete) SENSITIVE = [] include Aws::Structure end |