Class: Aws::AutoScaling::Types::DescribeAutoScalingInstancesType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeAutoScalingInstancesType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_ids ⇒ Array<String>
The IDs of the instances.
-
#max_records ⇒ Integer
The maximum number of items to return with this call.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#instance_ids ⇒ Array<String>
The IDs of the instances. If you omit this property, all Auto Scaling instances are described. If you specify an ID that does not exist, it is ignored with no error.
Array Members: Maximum number of 50 items.
2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2239 class DescribeAutoScalingInstancesType < Struct.new( :instance_ids, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of items to return with this call. The default
value is 50 and the maximum value is 50.
2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2239 class DescribeAutoScalingInstancesType < Struct.new( :instance_ids, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2239 class DescribeAutoScalingInstancesType < Struct.new( :instance_ids, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |