Class: Aws::AutoScaling::Types::DescribeInstanceRefreshesAnswer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_refreshesArray<Types::InstanceRefresh>

The instance refreshes for the specified group, sorted by creation timestamp in descending order.

Returns:



2274
2275
2276
2277
2278
2279
# File 'lib/aws-sdk-autoscaling/types.rb', line 2274

class DescribeInstanceRefreshesAnswer < Struct.new(
  :instance_refreshes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A string that indicates that the response contains more items than can be returned in a single response. To receive additional items, specify this string for the NextToken value when requesting the next set of items. This value is null when there are no more items to return.

Returns:

  • (String)


2274
2275
2276
2277
2278
2279
# File 'lib/aws-sdk-autoscaling/types.rb', line 2274

class DescribeInstanceRefreshesAnswer < Struct.new(
  :instance_refreshes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end