Class: Aws::AutoScaling::Types::DescribeLoadBalancerTargetGroupsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#load_balancer_target_groupsArray<Types::LoadBalancerTargetGroupState>

Information about the target groups.



2368
2369
2370
2371
2372
2373
# File 'lib/aws-sdk-autoscaling/types.rb', line 2368

class DescribeLoadBalancerTargetGroupsResponse < Struct.new(
  :load_balancer_target_groups,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A string that indicates that the response contains more items than can be returned in a single response. To receive additional items, specify this string for the NextToken value when requesting the next set of items. This value is null when there are no more items to return.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
# File 'lib/aws-sdk-autoscaling/types.rb', line 2368

class DescribeLoadBalancerTargetGroupsResponse < Struct.new(
  :load_balancer_target_groups,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end