Class: Aws::AutoScaling::Types::DescribeLoadBalancerTargetGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeLoadBalancerTargetGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#load_balancer_target_groups ⇒ Array<Types::LoadBalancerTargetGroupState>
Information about the target groups.
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
Instance Attribute Details
#load_balancer_target_groups ⇒ Array<Types::LoadBalancerTargetGroupState>
Information about the target groups.
2368 2369 2370 2371 2372 2373 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2368 class DescribeLoadBalancerTargetGroupsResponse < Struct.new( :load_balancer_target_groups, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
2368 2369 2370 2371 2372 2373 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2368 class DescribeLoadBalancerTargetGroupsResponse < Struct.new( :load_balancer_target_groups, :next_token) SENSITIVE = [] include Aws::Structure end |