Class: Aws::AutoScaling::Types::DescribeLoadBalancersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#load_balancersArray<Types::LoadBalancerState>

The load balancers.

Returns:



2413
2414
2415
2416
2417
2418
# File 'lib/aws-sdk-autoscaling/types.rb', line 2413

class DescribeLoadBalancersResponse < Struct.new(
  :load_balancers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A string that indicates that the response contains more items than can be returned in a single response. To receive additional items, specify this string for the NextToken value when requesting the next set of items. This value is null when there are no more items to return.

Returns:

  • (String)


2413
2414
2415
2416
2417
2418
# File 'lib/aws-sdk-autoscaling/types.rb', line 2413

class DescribeLoadBalancersResponse < Struct.new(
  :load_balancers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end