Class: Aws::AutoScaling::Types::DescribeNotificationConfigurationsAnswer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A string that indicates that the response contains more items than can be returned in a single response. To receive additional items, specify this string for the NextToken value when requesting the next set of items. This value is null when there are no more items to return.

Returns:

  • (String)


2467
2468
2469
2470
2471
2472
# File 'lib/aws-sdk-autoscaling/types.rb', line 2467

class DescribeNotificationConfigurationsAnswer < Struct.new(
  :notification_configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#notification_configurationsArray<Types::NotificationConfiguration>

The notification configurations.



2467
2468
2469
2470
2471
2472
# File 'lib/aws-sdk-autoscaling/types.rb', line 2467

class DescribeNotificationConfigurationsAnswer < Struct.new(
  :notification_configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end