Class: Aws::AutoScaling::Types::DescribeNotificationConfigurationsAnswer
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeNotificationConfigurationsAnswer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
-
#notification_configurations ⇒ Array<Types::NotificationConfiguration>
The notification configurations.
Instance Attribute Details
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
2467 2468 2469 2470 2471 2472 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2467 class DescribeNotificationConfigurationsAnswer < Struct.new( :notification_configurations, :next_token) SENSITIVE = [] include Aws::Structure end |
#notification_configurations ⇒ Array<Types::NotificationConfiguration>
The notification configurations.
2467 2468 2469 2470 2471 2472 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2467 class DescribeNotificationConfigurationsAnswer < Struct.new( :notification_configurations, :next_token) SENSITIVE = [] include Aws::Structure end |