Class: Aws::AutoScaling::Types::DescribeScalingActivitiesType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeScalingActivitiesType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activity_ids ⇒ Array<String>
The activity IDs of the desired scaling activities.
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#filters ⇒ Array<Types::Filter>
One or more filters to limit the results based on specific criteria.
-
#include_deleted_groups ⇒ Boolean
Indicates whether to include scaling activity from deleted Auto Scaling groups.
-
#max_records ⇒ Integer
The maximum number of items to return with this call.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#activity_ids ⇒ Array<String>
The activity IDs of the desired scaling activities. If unknown activity IDs are requested, they are ignored with no error. Only activities started within the last six weeks can be returned regardless of the activity IDs specified. If other filters are specified with the request, only results matching all filter criteria can be returned.
Array Members: Maximum number of 50 IDs.
2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2587 class DescribeScalingActivitiesType < Struct.new( :activity_ids, :auto_scaling_group_name, :include_deleted_groups, :max_records, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
Omitting this property performs an account-wide operation, which can result in slower or timed-out requests.
2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2587 class DescribeScalingActivitiesType < Struct.new( :activity_ids, :auto_scaling_group_name, :include_deleted_groups, :max_records, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
One or more filters to limit the results based on specific criteria. The following filters are supported:
-
‘StartTimeLowerBound` - The earliest scaling activities to return based on the activity start time. Scaling activities with a start time earlier than this value are not included in the results. Only activities started within the last six weeks can be returned regardless of the value specified.
-
‘StartTimeUpperBound` - The latest scaling activities to return based on the activity start time. Scaling activities with a start time later than this value are not included in the results. Only activities started within the last six weeks can be returned regardless of the value specified.
-
‘Status` - The `StatusCode` value of the scaling activity. This filter can only be used in combination with the `AutoScalingGroupName` parameter. For valid `StatusCode` values, see [Activity] in the *Amazon EC2 Auto Scaling API Reference*.
‘StartTimeLowerBound` and `StartTimeUpperBound` accept ISO 8601 formatted timestamps. Timestamps without a timezone offset are assumed to be UTC.
-
‘2000-01-18T08:15:00Z`
-
‘2000-01-18T16:15:00+08:00`
[1]: docs.aws.amazon.com/autoscaling/ec2/APIReference/API_Activity.html
2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2587 class DescribeScalingActivitiesType < Struct.new( :activity_ids, :auto_scaling_group_name, :include_deleted_groups, :max_records, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#include_deleted_groups ⇒ Boolean
Indicates whether to include scaling activity from deleted Auto Scaling groups.
2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2587 class DescribeScalingActivitiesType < Struct.new( :activity_ids, :auto_scaling_group_name, :include_deleted_groups, :max_records, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of items to return with this call. The default value is ‘100` and the maximum value is `100`.
2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2587 class DescribeScalingActivitiesType < Struct.new( :activity_ids, :auto_scaling_group_name, :include_deleted_groups, :max_records, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2587 class DescribeScalingActivitiesType < Struct.new( :activity_ids, :auto_scaling_group_name, :include_deleted_groups, :max_records, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |