Class: Aws::AutoScaling::Types::DescribeTrafficSourcesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

This string indicates that the response contains more items than can be returned in a single response. To receive additional items, specify this string for the NextToken value when requesting the next set of items. This value is null when there are no more items to return.

Returns:

  • (String)


2756
2757
2758
2759
2760
2761
# File 'lib/aws-sdk-autoscaling/types.rb', line 2756

class DescribeTrafficSourcesResponse < Struct.new(
  :traffic_sources,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#traffic_sourcesArray<Types::TrafficSourceState>

Information about the traffic sources.

Returns:



2756
2757
2758
2759
2760
2761
# File 'lib/aws-sdk-autoscaling/types.rb', line 2756

class DescribeTrafficSourcesResponse < Struct.new(
  :traffic_sources,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end