Class: Aws::AutoScaling::Types::DescribeTrafficSourcesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeTrafficSourcesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
This string indicates that the response contains more items than can be returned in a single response.
-
#traffic_sources ⇒ Array<Types::TrafficSourceState>
Information about the traffic sources.
Instance Attribute Details
#next_token ⇒ String
This string indicates that the response contains more items than can
be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2756 class DescribeTrafficSourcesResponse < Struct.new( :traffic_sources, :next_token) SENSITIVE = [] include Aws::Structure end |
#traffic_sources ⇒ Array<Types::TrafficSourceState>
Information about the traffic sources.
2756 2757 2758 2759 2760 2761 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2756 class DescribeTrafficSourcesResponse < Struct.new( :traffic_sources, :next_token) SENSITIVE = [] include Aws::Structure end |