Class: Aws::AutoScaling::Types::DescribeWarmPoolAnswer
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DescribeWarmPoolAnswer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::Instance>
The instances that are currently in the warm pool.
-
#next_token ⇒ String
This string indicates that the response contains more items than can be returned in a single response.
-
#warm_pool_configuration ⇒ Types::WarmPoolConfiguration
The warm pool configuration details.
Instance Attribute Details
#instances ⇒ Array<Types::Instance>
The instances that are currently in the warm pool.
2787 2788 2789 2790 2791 2792 2793 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2787 class DescribeWarmPoolAnswer < Struct.new( :warm_pool_configuration, :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
This string indicates that the response contains more items than can
be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
2787 2788 2789 2790 2791 2792 2793 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2787 class DescribeWarmPoolAnswer < Struct.new( :warm_pool_configuration, :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#warm_pool_configuration ⇒ Types::WarmPoolConfiguration
The warm pool configuration details.
2787 2788 2789 2790 2791 2792 2793 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 2787 class DescribeWarmPoolAnswer < Struct.new( :warm_pool_configuration, :instances, :next_token) SENSITIVE = [] include Aws::Structure end |