Class: Aws::AutoScaling::Types::DisableMetricsCollectionQuery

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_nameString

The name of the Auto Scaling group.

Returns:

  • (String)


3022
3023
3024
3025
3026
3027
# File 'lib/aws-sdk-autoscaling/types.rb', line 3022

class DisableMetricsCollectionQuery < Struct.new(
  :auto_scaling_group_name,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end

#metricsArray<String>

Identifies the metrics to disable.

You can specify one or more of the following metrics:

  • GroupMinSize

  • GroupMaxSize

  • GroupDesiredCapacity

  • GroupInServiceInstances

  • GroupPendingInstances

  • GroupStandbyInstances

  • GroupTerminatingInstances

  • GroupTotalInstances

  • GroupInServiceCapacity

  • GroupPendingCapacity

  • GroupStandbyCapacity

  • GroupTerminatingCapacity

  • GroupTotalCapacity

  • WarmPoolDesiredCapacity

  • WarmPoolWarmedCapacity

  • WarmPoolPendingCapacity

  • WarmPoolTerminatingCapacity

  • WarmPoolTotalCapacity

  • GroupAndWarmPoolDesiredCapacity

  • GroupAndWarmPoolTotalCapacity

If you omit this property, all metrics are disabled.

For more information, see Amazon CloudWatch metrics for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

Returns:

  • (Array<String>)


3022
3023
3024
3025
3026
3027
# File 'lib/aws-sdk-autoscaling/types.rb', line 3022

class DisableMetricsCollectionQuery < Struct.new(
  :auto_scaling_group_name,
  :metrics)
  SENSITIVE = []
  include Aws::Structure
end