Class: Aws::AutoScaling::Types::DistributionSegment
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::DistributionSegment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Use this structure to specify the capacity types that Amazon EC2 Auto Scaling prioritizes when it launches instances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_capacity_types ⇒ Array<String>
The capacity types to prioritize, in order.
Instance Attribute Details
#target_capacity_types ⇒ Array<String>
The capacity types to prioritize, in order. Amazon EC2 Auto Scaling
attempts to launch instances in the priority order of the capacity
types, and within each capacity type, in the order of instance types
listed in your launch template Overrides.
The following lists the valid values:
on-demand-capacity-reservation
: On-Demand Capacity Reservations.
capacity-block
: Capacity Blocks.
interruptible-capacity-reservation
: Interruptible Capacity Reservations.
on-demand
: On-Demand capacity. Include this value to allow the group to fall back to On-Demand capacity when the preceding capacity types are unavailable.
3066 3067 3068 3069 3070 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 3066 class DistributionSegment < Struct.new( :target_capacity_types) SENSITIVE = [] include Aws::Structure end |