Class: Aws::AutoScaling::Types::Metric
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::Metric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Represents a specific metric.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<Types::MetricDimension>
The dimensions for the metric.
-
#metric_name ⇒ String
The name of the metric.
-
#namespace ⇒ String
The namespace of the metric.
Instance Attribute Details
#dimensions ⇒ Array<Types::MetricDimension>
The dimensions for the metric. For the list of available dimensions, see the Amazon Web Services documentation available from the table in Amazon Web Services services that publish CloudWatch metrics in the Amazon CloudWatch User Guide.
Conditional: If you published your metric with dimensions, you must specify the same dimensions in your scaling policy.
5703 5704 5705 5706 5707 5708 5709 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5703 class Metric < Struct.new( :namespace, :metric_name, :dimensions) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric.
5703 5704 5705 5706 5707 5708 5709 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5703 class Metric < Struct.new( :namespace, :metric_name, :dimensions) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the metric. For more information, see the table in Amazon Web Services services that publish CloudWatch metrics in the Amazon CloudWatch User Guide.
5703 5704 5705 5706 5707 5708 5709 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 5703 class Metric < Struct.new( :namespace, :metric_name, :dimensions) SENSITIVE = [] include Aws::Structure end |