Class: Aws::AutoScaling::Types::Metric

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Represents a specific metric.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dimensionsArray<Types::MetricDimension>

The dimensions for the metric. For the list of available dimensions, see the Amazon Web Services documentation available from the table in Amazon Web Services services that publish CloudWatch metrics in the Amazon CloudWatch User Guide.

Conditional: If you published your metric with dimensions, you must specify the same dimensions in your scaling policy.

Returns:



5682
5683
5684
5685
5686
5687
5688
# File 'lib/aws-sdk-autoscaling/types.rb', line 5682

class Metric < Struct.new(
  :namespace,
  :metric_name,
  :dimensions)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the metric.

Returns:

  • (String)


5682
5683
5684
5685
5686
5687
5688
# File 'lib/aws-sdk-autoscaling/types.rb', line 5682

class Metric < Struct.new(
  :namespace,
  :metric_name,
  :dimensions)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace of the metric. For more information, see the table in Amazon Web Services services that publish CloudWatch metrics in the Amazon CloudWatch User Guide.

Returns:

  • (String)


5682
5683
5684
5685
5686
5687
5688
# File 'lib/aws-sdk-autoscaling/types.rb', line 5682

class Metric < Struct.new(
  :namespace,
  :metric_name,
  :dimensions)
  SENSITIVE = []
  include Aws::Structure
end