Class: Aws::AutoScaling::Types::MixedInstancesPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Use this structure to launch multiple instance types and On-Demand Instances and Spot Instances within a single Auto Scaling group.

A mixed instances policy contains information that Amazon EC2 Auto Scaling can use to launch instances and help optimize your costs. For more information, see Auto Scaling groups with multiple instance types and purchase options in the Amazon EC2 Auto Scaling User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instances_distributionTypes::InstancesDistribution

The instances distribution.



5914
5915
5916
5917
5918
5919
# File 'lib/aws-sdk-autoscaling/types.rb', line 5914

class MixedInstancesPolicy < Struct.new(
  :launch_template,
  :instances_distribution)
  SENSITIVE = []
  include Aws::Structure
end

#launch_templateTypes::LaunchTemplate

One or more launch templates and the instance types (overrides) that are used to launch EC2 instances to fulfill On-Demand and Spot capacities.



5914
5915
5916
5917
5918
5919
# File 'lib/aws-sdk-autoscaling/types.rb', line 5914

class MixedInstancesPolicy < Struct.new(
  :launch_template,
  :instances_distribution)
  SENSITIVE = []
  include Aws::Structure
end