Class: Aws::AutoScaling::Types::Operator
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::Operator
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Describes the entity that manages an Auto Scaling group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#principal ⇒ String
The service principal that is authorized to manage the Auto Scaling group.
Instance Attribute Details
#principal ⇒ String
The service principal that is authorized to manage the Auto Scaling group. When an operator is specified, only the designated operator service principal can make mutating changes to the Auto Scaling group.
6065 6066 6067 6068 6069 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6065 class Operator < Struct.new( :principal) SENSITIVE = [] include Aws::Structure end |