Class: Aws::AutoScaling::Types::Operator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Describes the entity that manages an Auto Scaling group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#principalString

The service principal that is authorized to manage the Auto Scaling group. When an operator is specified, only the designated operator service principal can make mutating changes to the Auto Scaling group.

Returns:

  • (String)


6044
6045
6046
6047
6048
# File 'lib/aws-sdk-autoscaling/types.rb', line 6044

class Operator < Struct.new(
  :principal)
  SENSITIVE = []
  include Aws::Structure
end