Class: Aws::AutoScaling::Types::PoliciesType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::PoliciesType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
-
#scaling_policies ⇒ Array<Types::ScalingPolicy>
The scaling policies.
Instance Attribute Details
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
6210 6211 6212 6213 6214 6215 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6210 class PoliciesType < Struct.new( :scaling_policies, :next_token) SENSITIVE = [] include Aws::Structure end |
#scaling_policies ⇒ Array<Types::ScalingPolicy>
The scaling policies.
6210 6211 6212 6213 6214 6215 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6210 class PoliciesType < Struct.new( :scaling_policies, :next_token) SENSITIVE = [] include Aws::Structure end |