Class: Aws::AutoScaling::Types::PoliciesType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A string that indicates that the response contains more items than can be returned in a single response. To receive additional items, specify this string for the NextToken value when requesting the next set of items. This value is null when there are no more items to return.

Returns:

  • (String)


6093
6094
6095
6096
6097
6098
# File 'lib/aws-sdk-autoscaling/types.rb', line 6093

class PoliciesType < Struct.new(
  :scaling_policies,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_policiesArray<Types::ScalingPolicy>

The scaling policies.

Returns:



6093
6094
6095
6096
6097
6098
# File 'lib/aws-sdk-autoscaling/types.rb', line 6093

class PoliciesType < Struct.new(
  :scaling_policies,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end