Class: Aws::AutoScaling::Types::PutNotificationConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::PutNotificationConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#notification_types ⇒ Array<String>
The type of event that causes the notification to be sent.
-
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS topic.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
6758 6759 6760 6761 6762 6763 6764 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6758 class PutNotificationConfigurationType < Struct.new( :auto_scaling_group_name, :topic_arn, :notification_types) SENSITIVE = [] include Aws::Structure end |
#notification_types ⇒ Array<String>
The type of event that causes the notification to be sent. To query the notification types supported by Amazon EC2 Auto Scaling, call the DescribeAutoScalingNotificationTypes API.
6758 6759 6760 6761 6762 6763 6764 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6758 class PutNotificationConfigurationType < Struct.new( :auto_scaling_group_name, :topic_arn, :notification_types) SENSITIVE = [] include Aws::Structure end |
#topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS topic.
6758 6759 6760 6761 6762 6763 6764 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 6758 class PutNotificationConfigurationType < Struct.new( :auto_scaling_group_name, :topic_arn, :notification_types) SENSITIVE = [] include Aws::Structure end |