Class: Aws::AutoScaling::Types::RollbackDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::RollbackDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Details about an instance refresh rollback.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances_to_update_on_rollback ⇒ Integer
Indicates the value of
InstancesToUpdateat the time the rollback started. -
#percentage_complete_on_rollback ⇒ Integer
Indicates the value of
PercentageCompleteat the time the rollback started. -
#progress_details_on_rollback ⇒ Types::InstanceRefreshProgressDetails
Reports progress on replacing instances in an Auto Scaling group that has a warm pool.
-
#rollback_reason ⇒ String
The reason for this instance refresh rollback (for example, whether a manual or automatic rollback was initiated).
-
#rollback_start_time ⇒ Time
The date and time at which the rollback began.
Instance Attribute Details
#instances_to_update_on_rollback ⇒ Integer
Indicates the value of InstancesToUpdate at the time the rollback
started.
7429 7430 7431 7432 7433 7434 7435 7436 7437 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7429 class RollbackDetails < Struct.new( :rollback_reason, :rollback_start_time, :percentage_complete_on_rollback, :instances_to_update_on_rollback, :progress_details_on_rollback) SENSITIVE = [] include Aws::Structure end |
#percentage_complete_on_rollback ⇒ Integer
Indicates the value of PercentageComplete at the time the rollback
started.
7429 7430 7431 7432 7433 7434 7435 7436 7437 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7429 class RollbackDetails < Struct.new( :rollback_reason, :rollback_start_time, :percentage_complete_on_rollback, :instances_to_update_on_rollback, :progress_details_on_rollback) SENSITIVE = [] include Aws::Structure end |
#progress_details_on_rollback ⇒ Types::InstanceRefreshProgressDetails
Reports progress on replacing instances in an Auto Scaling group that has a warm pool. This includes separate details for instances in the warm pool and instances in the Auto Scaling group (the live pool).
7429 7430 7431 7432 7433 7434 7435 7436 7437 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7429 class RollbackDetails < Struct.new( :rollback_reason, :rollback_start_time, :percentage_complete_on_rollback, :instances_to_update_on_rollback, :progress_details_on_rollback) SENSITIVE = [] include Aws::Structure end |
#rollback_reason ⇒ String
The reason for this instance refresh rollback (for example, whether a manual or automatic rollback was initiated).
7429 7430 7431 7432 7433 7434 7435 7436 7437 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7429 class RollbackDetails < Struct.new( :rollback_reason, :rollback_start_time, :percentage_complete_on_rollback, :instances_to_update_on_rollback, :progress_details_on_rollback) SENSITIVE = [] include Aws::Structure end |
#rollback_start_time ⇒ Time
The date and time at which the rollback began.
7429 7430 7431 7432 7433 7434 7435 7436 7437 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7429 class RollbackDetails < Struct.new( :rollback_reason, :rollback_start_time, :percentage_complete_on_rollback, :instances_to_update_on_rollback, :progress_details_on_rollback) SENSITIVE = [] include Aws::Structure end |