Class: Aws::AutoScaling::Types::ScheduledActionsType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A string that indicates that the response contains more items than can be returned in a single response. To receive additional items, specify this string for the NextToken value when requesting the next set of items. This value is null when there are no more items to return.

Returns:

  • (String)


7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-autoscaling/types.rb', line 7677

class ScheduledActionsType < Struct.new(
  :scheduled_update_group_actions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_update_group_actionsArray<Types::ScheduledUpdateGroupAction>

The scheduled actions.



7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-autoscaling/types.rb', line 7677

class ScheduledActionsType < Struct.new(
  :scheduled_update_group_actions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end