Class: Aws::AutoScaling::Types::ScheduledActionsType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-autoscaling/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A string that indicates that the response contains more items than can be returned in a single response. To receive additional items, specify this string for the NextToken value when requesting the next set of items. This value is null when there are no more items to return.

Returns:

  • (String)


7645
7646
7647
7648
7649
7650
# File 'lib/aws-sdk-autoscaling/types.rb', line 7645

class ScheduledActionsType < Struct.new(
  :scheduled_update_group_actions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_update_group_actionsArray<Types::ScheduledUpdateGroupAction>

The scheduled actions.



7645
7646
7647
7648
7649
7650
# File 'lib/aws-sdk-autoscaling/types.rb', line 7645

class ScheduledActionsType < Struct.new(
  :scheduled_update_group_actions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end