Class: Aws::AutoScaling::Types::ScheduledActionsType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::ScheduledActionsType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A string that indicates that the response contains more items than can be returned in a single response.
-
#scheduled_update_group_actions ⇒ Array<Types::ScheduledUpdateGroupAction>
The scheduled actions.
Instance Attribute Details
#next_token ⇒ String
A string that indicates that the response contains more items than
can be returned in a single response. To receive additional items,
specify this string for the NextToken value when requesting the
next set of items. This value is null when there are no more items
to return.
7612 7613 7614 7615 7616 7617 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7612 class ScheduledActionsType < Struct.new( :scheduled_update_group_actions, :next_token) SENSITIVE = [] include Aws::Structure end |
#scheduled_update_group_actions ⇒ Array<Types::ScheduledUpdateGroupAction>
The scheduled actions.
7612 7613 7614 7615 7616 7617 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7612 class ScheduledActionsType < Struct.new( :scheduled_update_group_actions, :next_token) SENSITIVE = [] include Aws::Structure end |