Class: Aws::AutoScaling::Types::ScheduledUpdateGroupAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::ScheduledUpdateGroupAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Describes a scheduled scaling action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
-
#desired_capacity ⇒ Integer
The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.
-
#end_time ⇒ Time
The date and time in UTC for the recurring schedule to end.
-
#max_size ⇒ Integer
The maximum size of the Auto Scaling group.
-
#min_size ⇒ Integer
The minimum size of the Auto Scaling group.
-
#recurrence ⇒ String
The recurring schedule for the action, in Unix cron syntax format.
-
#scheduled_action_arn ⇒ String
The Amazon Resource Name (ARN) of the scheduled action.
-
#scheduled_action_name ⇒ String
The name of the scheduled action.
-
#start_time ⇒ Time
The date and time in UTC for this action to start.
-
#time ⇒ Time
This property is no longer used.
-
#time_zone ⇒ String
The time zone for the cron expression.
Instance Attribute Details
#auto_scaling_group_name ⇒ String
The name of the Auto Scaling group.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#desired_capacity ⇒ Integer
The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time in UTC for the recurring schedule to end. For
example, "2019-06-01T00:00:00Z".
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#max_size ⇒ Integer
The maximum size of the Auto Scaling group.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#min_size ⇒ Integer
The minimum size of the Auto Scaling group.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#recurrence ⇒ String
The recurring schedule for the action, in Unix cron syntax format.
When StartTime and EndTime are specified with Recurrence, they
form the boundaries of when the recurring action starts and stops.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#scheduled_action_arn ⇒ String
The Amazon Resource Name (ARN) of the scheduled action.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#scheduled_action_name ⇒ String
The name of the scheduled action.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time in UTC for this action to start. For example,
"2019-06-01T00:00:00Z".
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Time
This property is no longer used.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |
#time_zone ⇒ String
The time zone for the cron expression.
7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 7707 class ScheduledUpdateGroupAction < Struct.new( :auto_scaling_group_name, :scheduled_action_name, :scheduled_action_arn, :time, :start_time, :end_time, :recurrence, :min_size, :max_size, :desired_capacity, :time_zone) SENSITIVE = [] include Aws::Structure end |