Class: Aws::AutoScaling::Types::WarmPoolConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AutoScaling::Types::WarmPoolConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-autoscaling/types.rb
Overview
Describes a warm pool configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_reuse_policy ⇒ Types::InstanceReusePolicy
The instance reuse policy.
-
#max_group_prepared_capacity ⇒ Integer
The maximum number of instances that are allowed to be in the warm pool or in any state except
Terminatedfor the Auto Scaling group. -
#min_size ⇒ Integer
The minimum number of instances to maintain in the warm pool.
-
#pool_state ⇒ String
The instance state to transition to after the lifecycle actions are complete.
-
#status ⇒ String
The status of a warm pool that is marked for deletion.
Instance Attribute Details
#instance_reuse_policy ⇒ Types::InstanceReusePolicy
The instance reuse policy.
8933 8934 8935 8936 8937 8938 8939 8940 8941 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8933 class WarmPoolConfiguration < Struct.new( :max_group_prepared_capacity, :min_size, :pool_state, :status, :instance_reuse_policy) SENSITIVE = [] include Aws::Structure end |
#max_group_prepared_capacity ⇒ Integer
The maximum number of instances that are allowed to be in the warm
pool or in any state except Terminated for the Auto Scaling group.
8933 8934 8935 8936 8937 8938 8939 8940 8941 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8933 class WarmPoolConfiguration < Struct.new( :max_group_prepared_capacity, :min_size, :pool_state, :status, :instance_reuse_policy) SENSITIVE = [] include Aws::Structure end |
#min_size ⇒ Integer
The minimum number of instances to maintain in the warm pool.
8933 8934 8935 8936 8937 8938 8939 8940 8941 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8933 class WarmPoolConfiguration < Struct.new( :max_group_prepared_capacity, :min_size, :pool_state, :status, :instance_reuse_policy) SENSITIVE = [] include Aws::Structure end |
#pool_state ⇒ String
The instance state to transition to after the lifecycle actions are complete.
8933 8934 8935 8936 8937 8938 8939 8940 8941 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8933 class WarmPoolConfiguration < Struct.new( :max_group_prepared_capacity, :min_size, :pool_state, :status, :instance_reuse_policy) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of a warm pool that is marked for deletion.
8933 8934 8935 8936 8937 8938 8939 8940 8941 |
# File 'lib/aws-sdk-autoscaling/types.rb', line 8933 class WarmPoolConfiguration < Struct.new( :max_group_prepared_capacity, :min_size, :pool_state, :status, :instance_reuse_policy) SENSITIVE = [] include Aws::Structure end |